"""
write_motion_dfmf_file
======================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class write_motion_dfmf_file(Operator):
    """Write the invariant terms and the model data in a motion dfmf file

    Parameters
    ----------
    model_data : PropertyField
        Data describing the finite element model
    mode_shapes : FieldsContainer
        Fieldscontainers containing the mode shapes,
        which are cst and nor for the cms
        method
    lumped_mass : FieldsContainer
        Fieldscontainers containing the lumped mass
    field_coordinates : Field
        Coordinates of all nodes
    nod :
    used_node_index :
    eigenvalue :
    translational_mode_shape :
    rotational_mode_shape :
    invrt_1 : float
    invrt_2 :
    invrt_3 :
    invrt_4 :
    invrt_5 :
    invrt_6 :
    invrt_7 :
    invrt_8 :
    file_path : str
        Path with motion dfmf extension where the
        export occurs


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.result.write_motion_dfmf_file()

    >>> # Make input connections
    >>> my_model_data = dpf.PropertyField()
    >>> op.inputs.model_data.connect(my_model_data)
    >>> my_mode_shapes = dpf.FieldsContainer()
    >>> op.inputs.mode_shapes.connect(my_mode_shapes)
    >>> my_lumped_mass = dpf.FieldsContainer()
    >>> op.inputs.lumped_mass.connect(my_lumped_mass)
    >>> my_field_coordinates = dpf.Field()
    >>> op.inputs.field_coordinates.connect(my_field_coordinates)
    >>> my_nod = dpf.()
    >>> op.inputs.nod.connect(my_nod)
    >>> my_used_node_index = dpf.()
    >>> op.inputs.used_node_index.connect(my_used_node_index)
    >>> my_eigenvalue = dpf.()
    >>> op.inputs.eigenvalue.connect(my_eigenvalue)
    >>> my_translational_mode_shape = dpf.()
    >>> op.inputs.translational_mode_shape.connect(my_translational_mode_shape)
    >>> my_rotational_mode_shape = dpf.()
    >>> op.inputs.rotational_mode_shape.connect(my_rotational_mode_shape)
    >>> my_invrt_1 = float()
    >>> op.inputs.invrt_1.connect(my_invrt_1)
    >>> my_invrt_2 = dpf.()
    >>> op.inputs.invrt_2.connect(my_invrt_2)
    >>> my_invrt_3 = dpf.()
    >>> op.inputs.invrt_3.connect(my_invrt_3)
    >>> my_invrt_4 = dpf.()
    >>> op.inputs.invrt_4.connect(my_invrt_4)
    >>> my_invrt_5 = dpf.()
    >>> op.inputs.invrt_5.connect(my_invrt_5)
    >>> my_invrt_6 = dpf.()
    >>> op.inputs.invrt_6.connect(my_invrt_6)
    >>> my_invrt_7 = dpf.()
    >>> op.inputs.invrt_7.connect(my_invrt_7)
    >>> my_invrt_8 = dpf.()
    >>> op.inputs.invrt_8.connect(my_invrt_8)
    >>> my_file_path = str()
    >>> op.inputs.file_path.connect(my_file_path)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.result.write_motion_dfmf_file(
    ...     model_data=my_model_data,
    ...     mode_shapes=my_mode_shapes,
    ...     lumped_mass=my_lumped_mass,
    ...     field_coordinates=my_field_coordinates,
    ...     nod=my_nod,
    ...     used_node_index=my_used_node_index,
    ...     eigenvalue=my_eigenvalue,
    ...     translational_mode_shape=my_translational_mode_shape,
    ...     rotational_mode_shape=my_rotational_mode_shape,
    ...     invrt_1=my_invrt_1,
    ...     invrt_2=my_invrt_2,
    ...     invrt_3=my_invrt_3,
    ...     invrt_4=my_invrt_4,
    ...     invrt_5=my_invrt_5,
    ...     invrt_6=my_invrt_6,
    ...     invrt_7=my_invrt_7,
    ...     invrt_8=my_invrt_8,
    ...     file_path=my_file_path,
    ... )

    >>> # Get output data
    >>> result_dfmf_data_source = op.outputs.dfmf_data_source()
    """

    def __init__(
        self,
        model_data=None,
        mode_shapes=None,
        lumped_mass=None,
        field_coordinates=None,
        nod=None,
        used_node_index=None,
        eigenvalue=None,
        translational_mode_shape=None,
        rotational_mode_shape=None,
        invrt_1=None,
        invrt_2=None,
        invrt_3=None,
        invrt_4=None,
        invrt_5=None,
        invrt_6=None,
        invrt_7=None,
        invrt_8=None,
        file_path=None,
        config=None,
        server=None,
    ):
        super().__init__(name="write_motion_dfmf_file", config=config, server=server)
        self._inputs = InputsWriteMotionDfmfFile(self)
        self._outputs = OutputsWriteMotionDfmfFile(self)
        if model_data is not None:
            self.inputs.model_data.connect(model_data)
        if mode_shapes is not None:
            self.inputs.mode_shapes.connect(mode_shapes)
        if lumped_mass is not None:
            self.inputs.lumped_mass.connect(lumped_mass)
        if field_coordinates is not None:
            self.inputs.field_coordinates.connect(field_coordinates)
        if nod is not None:
            self.inputs.nod.connect(nod)
        if used_node_index is not None:
            self.inputs.used_node_index.connect(used_node_index)
        if eigenvalue is not None:
            self.inputs.eigenvalue.connect(eigenvalue)
        if translational_mode_shape is not None:
            self.inputs.translational_mode_shape.connect(translational_mode_shape)
        if rotational_mode_shape is not None:
            self.inputs.rotational_mode_shape.connect(rotational_mode_shape)
        if invrt_1 is not None:
            self.inputs.invrt_1.connect(invrt_1)
        if invrt_2 is not None:
            self.inputs.invrt_2.connect(invrt_2)
        if invrt_3 is not None:
            self.inputs.invrt_3.connect(invrt_3)
        if invrt_4 is not None:
            self.inputs.invrt_4.connect(invrt_4)
        if invrt_5 is not None:
            self.inputs.invrt_5.connect(invrt_5)
        if invrt_6 is not None:
            self.inputs.invrt_6.connect(invrt_6)
        if invrt_7 is not None:
            self.inputs.invrt_7.connect(invrt_7)
        if invrt_8 is not None:
            self.inputs.invrt_8.connect(invrt_8)
        if file_path is not None:
            self.inputs.file_path.connect(file_path)

    @staticmethod
    def _spec():
        description = (
            """Write the invariant terms and the model data in a motion dfmf file"""
        )
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="model_data",
                    type_names=["property_field"],
                    optional=False,
                    document="""Data describing the finite element model""",
                ),
                1: PinSpecification(
                    name="mode_shapes",
                    type_names=["fields_container"],
                    optional=False,
                    document="""Fieldscontainers containing the mode shapes,
        which are cst and nor for the cms
        method""",
                ),
                2: PinSpecification(
                    name="lumped_mass",
                    type_names=["fields_container"],
                    optional=False,
                    document="""Fieldscontainers containing the lumped mass""",
                ),
                3: PinSpecification(
                    name="field_coordinates",
                    type_names=["field"],
                    optional=False,
                    document="""Coordinates of all nodes""",
                ),
                4: PinSpecification(
                    name="nod",
                    type_names=["vector<int32>"],
                    optional=False,
                    document="""""",
                ),
                5: PinSpecification(
                    name="used_node_index",
                    type_names=["vector<int32>"],
                    optional=False,
                    document="""""",
                ),
                6: PinSpecification(
                    name="eigenvalue",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                7: PinSpecification(
                    name="translational_mode_shape",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                8: PinSpecification(
                    name="rotational_mode_shape",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                9: PinSpecification(
                    name="invrt_1",
                    type_names=["double"],
                    optional=False,
                    document="""""",
                ),
                10: PinSpecification(
                    name="invrt_2",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                11: PinSpecification(
                    name="invrt_3",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                12: PinSpecification(
                    name="invrt_4",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                13: PinSpecification(
                    name="invrt_5",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                14: PinSpecification(
                    name="invrt_6",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                15: PinSpecification(
                    name="invrt_7",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                16: PinSpecification(
                    name="invrt_8",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                17: PinSpecification(
                    name="file_path",
                    type_names=["string"],
                    optional=False,
                    document="""Path with motion dfmf extension where the
        export occurs""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="dfmf_data_source",
                    type_names=["data_sources"],
                    optional=False,
                    document="""Data source containing the dfmf file
        generated.""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="write_motion_dfmf_file", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsWriteMotionDfmfFile
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsWriteMotionDfmfFile
        """
        return super().outputs


class InputsWriteMotionDfmfFile(_Inputs):
    """Intermediate class used to connect user inputs to
    write_motion_dfmf_file operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.write_motion_dfmf_file()
    >>> my_model_data = dpf.PropertyField()
    >>> op.inputs.model_data.connect(my_model_data)
    >>> my_mode_shapes = dpf.FieldsContainer()
    >>> op.inputs.mode_shapes.connect(my_mode_shapes)
    >>> my_lumped_mass = dpf.FieldsContainer()
    >>> op.inputs.lumped_mass.connect(my_lumped_mass)
    >>> my_field_coordinates = dpf.Field()
    >>> op.inputs.field_coordinates.connect(my_field_coordinates)
    >>> my_nod = dpf.()
    >>> op.inputs.nod.connect(my_nod)
    >>> my_used_node_index = dpf.()
    >>> op.inputs.used_node_index.connect(my_used_node_index)
    >>> my_eigenvalue = dpf.()
    >>> op.inputs.eigenvalue.connect(my_eigenvalue)
    >>> my_translational_mode_shape = dpf.()
    >>> op.inputs.translational_mode_shape.connect(my_translational_mode_shape)
    >>> my_rotational_mode_shape = dpf.()
    >>> op.inputs.rotational_mode_shape.connect(my_rotational_mode_shape)
    >>> my_invrt_1 = float()
    >>> op.inputs.invrt_1.connect(my_invrt_1)
    >>> my_invrt_2 = dpf.()
    >>> op.inputs.invrt_2.connect(my_invrt_2)
    >>> my_invrt_3 = dpf.()
    >>> op.inputs.invrt_3.connect(my_invrt_3)
    >>> my_invrt_4 = dpf.()
    >>> op.inputs.invrt_4.connect(my_invrt_4)
    >>> my_invrt_5 = dpf.()
    >>> op.inputs.invrt_5.connect(my_invrt_5)
    >>> my_invrt_6 = dpf.()
    >>> op.inputs.invrt_6.connect(my_invrt_6)
    >>> my_invrt_7 = dpf.()
    >>> op.inputs.invrt_7.connect(my_invrt_7)
    >>> my_invrt_8 = dpf.()
    >>> op.inputs.invrt_8.connect(my_invrt_8)
    >>> my_file_path = str()
    >>> op.inputs.file_path.connect(my_file_path)
    """

    def __init__(self, op: Operator):
        super().__init__(write_motion_dfmf_file._spec().inputs, op)
        self._model_data = Input(write_motion_dfmf_file._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._model_data)
        self._mode_shapes = Input(
            write_motion_dfmf_file._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._mode_shapes)
        self._lumped_mass = Input(
            write_motion_dfmf_file._spec().input_pin(2), 2, op, -1
        )
        self._inputs.append(self._lumped_mass)
        self._field_coordinates = Input(
            write_motion_dfmf_file._spec().input_pin(3), 3, op, -1
        )
        self._inputs.append(self._field_coordinates)
        self._nod = Input(write_motion_dfmf_file._spec().input_pin(4), 4, op, -1)
        self._inputs.append(self._nod)
        self._used_node_index = Input(
            write_motion_dfmf_file._spec().input_pin(5), 5, op, -1
        )
        self._inputs.append(self._used_node_index)
        self._eigenvalue = Input(write_motion_dfmf_file._spec().input_pin(6), 6, op, -1)
        self._inputs.append(self._eigenvalue)
        self._translational_mode_shape = Input(
            write_motion_dfmf_file._spec().input_pin(7), 7, op, -1
        )
        self._inputs.append(self._translational_mode_shape)
        self._rotational_mode_shape = Input(
            write_motion_dfmf_file._spec().input_pin(8), 8, op, -1
        )
        self._inputs.append(self._rotational_mode_shape)
        self._invrt_1 = Input(write_motion_dfmf_file._spec().input_pin(9), 9, op, -1)
        self._inputs.append(self._invrt_1)
        self._invrt_2 = Input(write_motion_dfmf_file._spec().input_pin(10), 10, op, -1)
        self._inputs.append(self._invrt_2)
        self._invrt_3 = Input(write_motion_dfmf_file._spec().input_pin(11), 11, op, -1)
        self._inputs.append(self._invrt_3)
        self._invrt_4 = Input(write_motion_dfmf_file._spec().input_pin(12), 12, op, -1)
        self._inputs.append(self._invrt_4)
        self._invrt_5 = Input(write_motion_dfmf_file._spec().input_pin(13), 13, op, -1)
        self._inputs.append(self._invrt_5)
        self._invrt_6 = Input(write_motion_dfmf_file._spec().input_pin(14), 14, op, -1)
        self._inputs.append(self._invrt_6)
        self._invrt_7 = Input(write_motion_dfmf_file._spec().input_pin(15), 15, op, -1)
        self._inputs.append(self._invrt_7)
        self._invrt_8 = Input(write_motion_dfmf_file._spec().input_pin(16), 16, op, -1)
        self._inputs.append(self._invrt_8)
        self._file_path = Input(
            write_motion_dfmf_file._spec().input_pin(17), 17, op, -1
        )
        self._inputs.append(self._file_path)

    @property
    def model_data(self):
        """Allows to connect model_data input to the operator.

        Data describing the finite element model

        Parameters
        ----------
        my_model_data : PropertyField

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.model_data.connect(my_model_data)
        >>> # or
        >>> op.inputs.model_data(my_model_data)
        """
        return self._model_data

    @property
    def mode_shapes(self):
        """Allows to connect mode_shapes input to the operator.

        Fieldscontainers containing the mode shapes,
        which are cst and nor for the cms
        method

        Parameters
        ----------
        my_mode_shapes : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.mode_shapes.connect(my_mode_shapes)
        >>> # or
        >>> op.inputs.mode_shapes(my_mode_shapes)
        """
        return self._mode_shapes

    @property
    def lumped_mass(self):
        """Allows to connect lumped_mass input to the operator.

        Fieldscontainers containing the lumped mass

        Parameters
        ----------
        my_lumped_mass : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.lumped_mass.connect(my_lumped_mass)
        >>> # or
        >>> op.inputs.lumped_mass(my_lumped_mass)
        """
        return self._lumped_mass

    @property
    def field_coordinates(self):
        """Allows to connect field_coordinates input to the operator.

        Coordinates of all nodes

        Parameters
        ----------
        my_field_coordinates : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.field_coordinates.connect(my_field_coordinates)
        >>> # or
        >>> op.inputs.field_coordinates(my_field_coordinates)
        """
        return self._field_coordinates

    @property
    def nod(self):
        """Allows to connect nod input to the operator.

        Parameters
        ----------
        my_nod :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.nod.connect(my_nod)
        >>> # or
        >>> op.inputs.nod(my_nod)
        """
        return self._nod

    @property
    def used_node_index(self):
        """Allows to connect used_node_index input to the operator.

        Parameters
        ----------
        my_used_node_index :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.used_node_index.connect(my_used_node_index)
        >>> # or
        >>> op.inputs.used_node_index(my_used_node_index)
        """
        return self._used_node_index

    @property
    def eigenvalue(self):
        """Allows to connect eigenvalue input to the operator.

        Parameters
        ----------
        my_eigenvalue :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.eigenvalue.connect(my_eigenvalue)
        >>> # or
        >>> op.inputs.eigenvalue(my_eigenvalue)
        """
        return self._eigenvalue

    @property
    def translational_mode_shape(self):
        """Allows to connect translational_mode_shape input to the operator.

        Parameters
        ----------
        my_translational_mode_shape :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.translational_mode_shape.connect(my_translational_mode_shape)
        >>> # or
        >>> op.inputs.translational_mode_shape(my_translational_mode_shape)
        """
        return self._translational_mode_shape

    @property
    def rotational_mode_shape(self):
        """Allows to connect rotational_mode_shape input to the operator.

        Parameters
        ----------
        my_rotational_mode_shape :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.rotational_mode_shape.connect(my_rotational_mode_shape)
        >>> # or
        >>> op.inputs.rotational_mode_shape(my_rotational_mode_shape)
        """
        return self._rotational_mode_shape

    @property
    def invrt_1(self):
        """Allows to connect invrt_1 input to the operator.

        Parameters
        ----------
        my_invrt_1 : float

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.invrt_1.connect(my_invrt_1)
        >>> # or
        >>> op.inputs.invrt_1(my_invrt_1)
        """
        return self._invrt_1

    @property
    def invrt_2(self):
        """Allows to connect invrt_2 input to the operator.

        Parameters
        ----------
        my_invrt_2 :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.invrt_2.connect(my_invrt_2)
        >>> # or
        >>> op.inputs.invrt_2(my_invrt_2)
        """
        return self._invrt_2

    @property
    def invrt_3(self):
        """Allows to connect invrt_3 input to the operator.

        Parameters
        ----------
        my_invrt_3 :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.invrt_3.connect(my_invrt_3)
        >>> # or
        >>> op.inputs.invrt_3(my_invrt_3)
        """
        return self._invrt_3

    @property
    def invrt_4(self):
        """Allows to connect invrt_4 input to the operator.

        Parameters
        ----------
        my_invrt_4 :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.invrt_4.connect(my_invrt_4)
        >>> # or
        >>> op.inputs.invrt_4(my_invrt_4)
        """
        return self._invrt_4

    @property
    def invrt_5(self):
        """Allows to connect invrt_5 input to the operator.

        Parameters
        ----------
        my_invrt_5 :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.invrt_5.connect(my_invrt_5)
        >>> # or
        >>> op.inputs.invrt_5(my_invrt_5)
        """
        return self._invrt_5

    @property
    def invrt_6(self):
        """Allows to connect invrt_6 input to the operator.

        Parameters
        ----------
        my_invrt_6 :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.invrt_6.connect(my_invrt_6)
        >>> # or
        >>> op.inputs.invrt_6(my_invrt_6)
        """
        return self._invrt_6

    @property
    def invrt_7(self):
        """Allows to connect invrt_7 input to the operator.

        Parameters
        ----------
        my_invrt_7 :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.invrt_7.connect(my_invrt_7)
        >>> # or
        >>> op.inputs.invrt_7(my_invrt_7)
        """
        return self._invrt_7

    @property
    def invrt_8(self):
        """Allows to connect invrt_8 input to the operator.

        Parameters
        ----------
        my_invrt_8 :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.invrt_8.connect(my_invrt_8)
        >>> # or
        >>> op.inputs.invrt_8(my_invrt_8)
        """
        return self._invrt_8

    @property
    def file_path(self):
        """Allows to connect file_path input to the operator.

        Path with motion dfmf extension where the
        export occurs

        Parameters
        ----------
        my_file_path : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> op.inputs.file_path.connect(my_file_path)
        >>> # or
        >>> op.inputs.file_path(my_file_path)
        """
        return self._file_path


class OutputsWriteMotionDfmfFile(_Outputs):
    """Intermediate class used to get outputs from
    write_motion_dfmf_file operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.write_motion_dfmf_file()
    >>> # Connect inputs : op.inputs. ...
    >>> result_dfmf_data_source = op.outputs.dfmf_data_source()
    """

    def __init__(self, op: Operator):
        super().__init__(write_motion_dfmf_file._spec().outputs, op)
        self._dfmf_data_source = Output(
            write_motion_dfmf_file._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._dfmf_data_source)

    @property
    def dfmf_data_source(self):
        """Allows to get dfmf_data_source output of the operator

        Returns
        ----------
        my_dfmf_data_source : DataSources

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_motion_dfmf_file()
        >>> # Connect inputs : op.inputs. ...
        >>> result_dfmf_data_source = op.outputs.dfmf_data_source()
        """  # noqa: E501
        return self._dfmf_data_source



from .acceleration import acceleration 
from .acceleration_X import acceleration_X 
from .acceleration_Y import acceleration_Y 
from .acceleration_Z import acceleration_Z 
from .accu_eqv_creep_strain import accu_eqv_creep_strain 
from .accu_eqv_plastic_strain import accu_eqv_plastic_strain 
from .add_rigid_body_motion import add_rigid_body_motion 
from .add_rigid_body_motion_fc import add_rigid_body_motion_fc 
from .artificial_hourglass_energy import artificial_hourglass_energy 
from .beam_axial_force import beam_axial_force 
from .beam_axial_plastic_strain import beam_axial_plastic_strain 
from .beam_axial_stress import beam_axial_stress 
from .beam_axial_total_strain import beam_axial_total_strain 
from .beam_rs_shear_stress import beam_rs_shear_stress 
from .beam_s_bending_moment import beam_s_bending_moment 
from .beam_s_shear_force import beam_s_shear_force 
from .beam_t_bending_moment import beam_t_bending_moment 
from .beam_t_shear_force import beam_t_shear_force 
from .beam_torsional_moment import beam_torsional_moment 
from .beam_tr_shear_stress import beam_tr_shear_stress 
from .cms_dst_table_provider import cms_dst_table_provider 
from .cms_matrices_provider import cms_matrices_provider 
from .cms_subfile_info_provider import cms_subfile_info_provider 
from .co_energy import co_energy 
from .compute_invariant_terms_motion import compute_invariant_terms_motion 
from .compute_invariant_terms_rbd import compute_invariant_terms_rbd 
from .compute_stress import compute_stress 
from .compute_stress_1 import compute_stress_1 
from .compute_stress_2 import compute_stress_2 
from .compute_stress_3 import compute_stress_3 
from .compute_stress_X import compute_stress_X 
from .compute_stress_XY import compute_stress_XY 
from .compute_stress_XZ import compute_stress_XZ 
from .compute_stress_Y import compute_stress_Y 
from .compute_stress_YZ import compute_stress_YZ 
from .compute_stress_Z import compute_stress_Z 
from .compute_stress_von_mises import compute_stress_von_mises 
from .compute_total_strain import compute_total_strain 
from .compute_total_strain_1 import compute_total_strain_1 
from .compute_total_strain_2 import compute_total_strain_2 
from .compute_total_strain_3 import compute_total_strain_3 
from .compute_total_strain_X import compute_total_strain_X 
from .compute_total_strain_XY import compute_total_strain_XY 
from .compute_total_strain_XZ import compute_total_strain_XZ 
from .compute_total_strain_Y import compute_total_strain_Y 
from .compute_total_strain_YZ import compute_total_strain_YZ 
from .compute_total_strain_Z import compute_total_strain_Z 
from .contact_fluid_penetration_pressure import contact_fluid_penetration_pressure 
from .contact_friction_stress import contact_friction_stress 
from .contact_gap_distance import contact_gap_distance 
from .contact_penetration import contact_penetration 
from .contact_pressure import contact_pressure 
from .contact_sliding_distance import contact_sliding_distance 
from .contact_status import contact_status 
from .contact_surface_heat_flux import contact_surface_heat_flux 
from .contact_total_stress import contact_total_stress 
from .coordinate_system import coordinate_system 
from .coordinates import coordinates 
from .creep_strain_energy_density import creep_strain_energy_density 
from .current_density import current_density 
from .custom import custom 
from .cyclic_analytic_seqv_max import cyclic_analytic_seqv_max 
from .cyclic_analytic_usum_max import cyclic_analytic_usum_max 
from .cyclic_expanded_acceleration import cyclic_expanded_acceleration 
from .cyclic_expanded_displacement import cyclic_expanded_displacement 
from .cyclic_expanded_el_strain import cyclic_expanded_el_strain 
from .cyclic_expanded_enf import cyclic_expanded_enf 
from .cyclic_expanded_heat_flux import cyclic_expanded_heat_flux 
from .cyclic_expanded_stress import cyclic_expanded_stress 
from .cyclic_expanded_temperature import cyclic_expanded_temperature 
from .cyclic_expanded_velocity import cyclic_expanded_velocity 
from .cyclic_expansion import cyclic_expansion 
from .cyclic_kinetic_energy import cyclic_kinetic_energy 
from .cyclic_strain_energy import cyclic_strain_energy 
from .cyclic_volume import cyclic_volume 
from .density import density 
from .displacement import displacement 
from .displacement_X import displacement_X 
from .displacement_Y import displacement_Y 
from .displacement_Z import displacement_Z 
from .dynamic_viscosity import dynamic_viscosity 
from .elastic_strain import elastic_strain 
from .elastic_strain_X import elastic_strain_X 
from .elastic_strain_XY import elastic_strain_XY 
from .elastic_strain_XZ import elastic_strain_XZ 
from .elastic_strain_Y import elastic_strain_Y 
from .elastic_strain_YZ import elastic_strain_YZ 
from .elastic_strain_Z import elastic_strain_Z 
from .elastic_strain_energy_density import elastic_strain_energy_density 
from .elastic_strain_eqv import elastic_strain_eqv 
from .elastic_strain_principal_1 import elastic_strain_principal_1 
from .elastic_strain_principal_2 import elastic_strain_principal_2 
from .elastic_strain_principal_3 import elastic_strain_principal_3 
from .elastic_strain_rotation_by_euler_nodes import elastic_strain_rotation_by_euler_nodes 
from .electric_field import electric_field 
from .electric_flux_density import electric_flux_density 
from .electric_potential import electric_potential 
from .element_centroids import element_centroids 
from .element_nodal_forces import element_nodal_forces 
from .element_orientations import element_orientations 
from .elemental_heat_generation import elemental_heat_generation 
from .elemental_mass import elemental_mass 
from .elemental_volume import elemental_volume 
from .enf_rotation_by_euler_nodes import enf_rotation_by_euler_nodes 
from .enthalpy import enthalpy 
from .entropy import entropy 
from .epsilon import epsilon 
from .equivalent_mass import equivalent_mass 
from .equivalent_radiated_power import equivalent_radiated_power 
from .eqv_stress_parameter import eqv_stress_parameter 
from .erp_accumulate_results import erp_accumulate_results 
from .erp_radiation_efficiency import erp_radiation_efficiency 
from .euler_load_buckling import euler_load_buckling 
from .euler_nodes import euler_nodes 
from .global_added_mass import global_added_mass 
from .global_added_mass_pct import global_added_mass_pct 
from .global_center_mass import global_center_mass 
from .global_energy_ratio import global_energy_ratio 
from .global_energy_ratio_wo_eroded import global_energy_ratio_wo_eroded 
from .global_eroded_hourglass_energy import global_eroded_hourglass_energy 
from .global_eroded_internal_energy import global_eroded_internal_energy 
from .global_eroded_kinetic_energy import global_eroded_kinetic_energy 
from .global_external_work import global_external_work 
from .global_hourglass_energy import global_hourglass_energy 
from .global_internal_energy import global_internal_energy 
from .global_joint_internal_energy import global_joint_internal_energy 
from .global_kinetic_energy import global_kinetic_energy 
from .global_rigid_body_stopper_energy import global_rigid_body_stopper_energy 
from .global_sliding_interface_energy import global_sliding_interface_energy 
from .global_spring_damper_energy import global_spring_damper_energy 
from .global_system_damping_energy import global_system_damping_energy 
from .global_time_step import global_time_step 
from .global_to_nodal import global_to_nodal 
from .global_total_energy import global_total_energy 
from .global_total_mass import global_total_mass 
from .global_velocity import global_velocity 
from .heat_flux import heat_flux 
from .heat_flux_X import heat_flux_X 
from .heat_flux_Y import heat_flux_Y 
from .heat_flux_Z import heat_flux_Z 
from .hydrostatic_pressure import hydrostatic_pressure 
from .incremental_energy import incremental_energy 
from .initial_coordinates import initial_coordinates 
from .interface_contact_area import interface_contact_area 
from .interface_contact_force import interface_contact_force 
from .interface_contact_mass import interface_contact_mass 
from .interface_contact_moment import interface_contact_moment 
from .interface_resultant_contact_force import interface_resultant_contact_force 
from .joint_force_reaction import joint_force_reaction 
from .joint_moment_reaction import joint_moment_reaction 
from .joint_relative_acceleration import joint_relative_acceleration 
from .joint_relative_angular_acceleration import joint_relative_angular_acceleration 
from .joint_relative_angular_velocity import joint_relative_angular_velocity 
from .joint_relative_displacement import joint_relative_displacement 
from .joint_relative_rotation import joint_relative_rotation 
from .joint_relative_velocity import joint_relative_velocity 
from .kinetic_energy import kinetic_energy 
from .mach_number import mach_number 
from .mapdl_material_properties import mapdl_material_properties 
from .mapdl_section import mapdl_section 
from .mass_flow_rate import mass_flow_rate 
from .mass_fraction import mass_fraction 
from .material_property_of_element import material_property_of_element 
from .mean_static_pressure import mean_static_pressure 
from .mean_temperature import mean_temperature 
from .mean_velocity import mean_velocity 
from .members_in_bending_not_certified import members_in_bending_not_certified 
from .members_in_compression_not_certified import members_in_compression_not_certified 
from .members_in_linear_compression_bending_not_certified import members_in_linear_compression_bending_not_certified 
from .migrate_to_h5dpf import migrate_to_h5dpf 
from .modal_basis import modal_basis 
from .nmisc import nmisc 
from .nodal_force import nodal_force 
from .nodal_moment import nodal_moment 
from .nodal_rotation_by_euler_nodes import nodal_rotation_by_euler_nodes 
from .nodal_to_global import nodal_to_global 
from .normal_contact_force import normal_contact_force 
from .normal_contact_moment import normal_contact_moment 
from .num_surface_status_changes import num_surface_status_changes 
from .omega import omega 
from .part_added_mass import part_added_mass 
from .part_eroded_internal_energy import part_eroded_internal_energy 
from .part_eroded_kinetic_energy import part_eroded_kinetic_energy 
from .part_hourglass_energy import part_hourglass_energy 
from .part_internal_energy import part_internal_energy 
from .part_kinetic_energy import part_kinetic_energy 
from .part_momentum import part_momentum 
from .part_rigid_body_velocity import part_rigid_body_velocity 
from .plastic_state_variable import plastic_state_variable 
from .plastic_strain import plastic_strain 
from .plastic_strain_X import plastic_strain_X 
from .plastic_strain_XY import plastic_strain_XY 
from .plastic_strain_XZ import plastic_strain_XZ 
from .plastic_strain_Y import plastic_strain_Y 
from .plastic_strain_YZ import plastic_strain_YZ 
from .plastic_strain_Z import plastic_strain_Z 
from .plastic_strain_energy_density import plastic_strain_energy_density 
from .plastic_strain_eqv import plastic_strain_eqv 
from .plastic_strain_principal_1 import plastic_strain_principal_1 
from .plastic_strain_principal_2 import plastic_strain_principal_2 
from .plastic_strain_principal_3 import plastic_strain_principal_3 
from .plastic_strain_rotation_by_euler_nodes import plastic_strain_rotation_by_euler_nodes 
from .poynting_vector import poynting_vector 
from .poynting_vector_surface import poynting_vector_surface 
from .pres_to_field import pres_to_field 
from .pressure import pressure 
from .prns_to_field import prns_to_field 
from .raw_displacement import raw_displacement 
from .raw_reaction_force import raw_reaction_force 
from .reaction_force import reaction_force 
from .recombine_harmonic_indeces_cyclic import recombine_harmonic_indeces_cyclic 
from .remove_rigid_body_motion import remove_rigid_body_motion 
from .remove_rigid_body_motion_fc import remove_rigid_body_motion_fc 
from .rigid_transformation import rigid_transformation 
from .rms_static_pressure import rms_static_pressure 
from .rms_temperature import rms_temperature 
from .rms_velocity import rms_velocity 
from .rom_data_provider import rom_data_provider 
from .run import run 
from .smisc import smisc 
from .specific_heat import specific_heat 
from .static_pressure import static_pressure 
from .stiffness_matrix_energy import stiffness_matrix_energy 
from .strain_eqv_as_mechanical import strain_eqv_as_mechanical 
from .stress import stress 
from .stress_X import stress_X 
from .stress_XY import stress_XY 
from .stress_XZ import stress_XZ 
from .stress_Y import stress_Y 
from .stress_YZ import stress_YZ 
from .stress_Z import stress_Z 
from .stress_eqv_as_mechanical import stress_eqv_as_mechanical 
from .stress_principal_1 import stress_principal_1 
from .stress_principal_2 import stress_principal_2 
from .stress_principal_3 import stress_principal_3 
from .stress_ratio import stress_ratio 
from .stress_rotation_by_euler_nodes import stress_rotation_by_euler_nodes 
from .stress_von_mises import stress_von_mises 
from .structural_temperature import structural_temperature 
from .superficial_velocity import superficial_velocity 
from .surface_heat_rate import surface_heat_rate 
from .swelling_strains import swelling_strains 
from .tangential_contact_force import tangential_contact_force 
from .tangential_contact_moment import tangential_contact_moment 
from .temperature import temperature 
from .temperature_grad import temperature_grad 
from .thermal_conductivity import thermal_conductivity 
from .thermal_dissipation_energy import thermal_dissipation_energy 
from .thermal_strain import thermal_strain 
from .thermal_strain_X import thermal_strain_X 
from .thermal_strain_XY import thermal_strain_XY 
from .thermal_strain_XZ import thermal_strain_XZ 
from .thermal_strain_Y import thermal_strain_Y 
from .thermal_strain_YZ import thermal_strain_YZ 
from .thermal_strain_Z import thermal_strain_Z 
from .thermal_strain_principal_1 import thermal_strain_principal_1 
from .thermal_strain_principal_2 import thermal_strain_principal_2 
from .thermal_strain_principal_3 import thermal_strain_principal_3 
from .thermal_strains_eqv import thermal_strains_eqv 
from .thickness import thickness 
from .torque import torque 
from .total_contact_force import total_contact_force 
from .total_contact_moment import total_contact_moment 
from .total_mass import total_mass 
from .total_pressure import total_pressure 
from .total_strain import total_strain 
from .total_temperature import total_temperature 
from .transient_rayleigh_integration import transient_rayleigh_integration 
from .turbulent_kinetic_energy import turbulent_kinetic_energy 
from .turbulent_viscosity import turbulent_viscosity 
from .velocity import velocity 
from .velocity_X import velocity_X 
from .velocity_Y import velocity_Y 
from .velocity_Z import velocity_Z 
from .volume_fraction import volume_fraction 
from .wall_shear_stress import wall_shear_stress 
from .workflow_energy_per_component import workflow_energy_per_component 
from .workflow_energy_per_harmonic import workflow_energy_per_harmonic 
from .write_cms_rbd_file import write_cms_rbd_file 
from .write_motion_dfmf_file import write_motion_dfmf_file 
from .y_plus import y_plus 



"""
Common
======

.. autoclass:: locations
   :members:

"""
import re
import sys
from enum import Enum

from ansys.dpf.core.misc import module_exists
from ansys.dpf.gate.common import locations, ProgressBarBase  # noqa: F401
from ansys.dpf.gate.dpf_vector import (  # noqa: F401
    get_size_of_list as _get_size_of_list,
)


def _camel_to_snake_case(name):
    return re.sub(r"(?<!^)(?=[A-Z])", "_", name).lower()


def _remove_spaces(name):
    out = name.lower()
    out = out.replace(" ", "_")
    out = out.replace("-", "_")
    return out


def _make_as_function_name(name):
    out = name.lower()
    out = (
        out.replace(" ", "_")
        .replace("-", "_")
        .replace("/", "_")
        .replace(".", "_")
        .replace(":", "_")
        .replace(";", "_")
        .replace(",", "_")
        .replace("(", "")
        .replace(")", "")
    )
    return out


def _snake_to_camel_case(name):
    return "".join(word.title() for word in name.split("_"))


class _smart_dict_camel(dict):
    def __missing__(self, key):
        return _camel_to_snake_case(key)


class _smart_dict_unit_system(dict):
    def __missing__(self, key):
        return "unknown"


class types(Enum):
    """
    The ``'types'`` enum contains the available types passed through operators
    and workflows to DPF.



    """

    # Types from grpc proto, do not modify
    string = 0
    int = 1
    double = 2
    bool = 3
    field = 4
    collection = 5
    scoping = 6
    data_sources = 7
    meshed_region = 8
    time_freq_support = 9
    result_info = 10
    cyclic_support = 11
    property_field = 12
    workflow = 13
    run = 14
    any = 15
    vec_int = 16
    vec_double = 17
    support = 18
    operator = 19
    data_tree = 20
    vec_string = 21
    string_field = 22
    custom_type_field = 23
    generic_data_container = 24
    mesh_info = 25
    # Types not from grpc proto, added in Python
    fields_container = -1
    scopings_container = -2
    meshes_container = -3
    streams_container = -4


def types_enum_to_types():
    from ansys.dpf.core import (
        cyclic_support,
        data_sources,
        field,
        fields_container,
        collection,
        meshed_region,
        meshes_container,
        property_field,
        string_field,
        custom_type_field,
        result_info,
        scoping,
        scopings_container,
        time_freq_support,
        dpf_operator,
        data_tree,
        workflow,
        streams_container,
        generic_data_container,
        mesh_info,
    )
    from ansys.dpf.gate import dpf_vector

    return {
        types.string: str,
        types.int: int,
        types.double: float,
        types.bool: bool,
        types.collection: collection.Collection,
        types.fields_container: fields_container.FieldsContainer,
        types.scopings_container: scopings_container.ScopingsContainer,
        types.meshes_container: meshes_container.MeshesContainer,
        types.field: field.Field,
        types.data_sources: data_sources.DataSources,
        types.cyclic_support: cyclic_support.CyclicSupport,
        types.workflow: workflow.Workflow,
        types.time_freq_support: time_freq_support.TimeFreqSupport,
        types.meshed_region: meshed_region.MeshedRegion,
        types.result_info: result_info.ResultInfo,
        types.property_field: property_field.PropertyField,
        types.data_tree: data_tree.DataTree,
        types.operator: dpf_operator.Operator,
        types.scoping: scoping.Scoping,
        types.vec_int: dpf_vector.DPFVectorInt,
        types.vec_double: dpf_vector.DPFVectorDouble,
        types.string_field: string_field.StringField,
        types.custom_type_field: custom_type_field.CustomTypeField,
        types.streams_container: streams_container.StreamsContainer,
        types.generic_data_container: generic_data_container.GenericDataContainer,
        types.mesh_info: mesh_info.MeshInfo,
    }


class natures(Enum):
    """The ``'natures'`` enum contains the dimensionality types.
    It can be used to create a field of a given dimensionality.
    """

    scalar = 0
    vector = 1
    matrix = 2
    symmatrix = 5


class shell_layers(Enum):
    """The ``'shell_layers'`` enum contains the available order of
    shell layers (or lack of shell layers) that defines how the
    field's data is ordered.
    """

    notset = -1
    top = 0
    bottom = 1
    topbottom = 2
    mid = 3
    topbottommid = 4
    nonelayer = 5
    layerindependent = 6


class elemental_properties:
    """Contains strings to define elemental property fields.

    Attributes
    ----------
    element_shape = "elshape"
        element shape property data is provided

    element_type = "eltype"
        element type property data is provided

    connectivity = "connectivity"
        connectivity property data is provided

    material = "mat"
        material property data is provided

    element_properties = "elprops"
        element properties data is provided

    apdl_element_type = "apdl_element_type"
        apdl element type property data is provided

    elements_faces_connectivity = "elements_faces_connectivity"
        element faces connectivity property data is provided
    """

    element_shape = "elshape"
    element_type = "eltype"
    connectivity = "connectivity"
    material = "mat"
    element_properties = "elprops"
    apdl_element_type = "apdl_element_type"
    elements_faces_connectivity = "elements_faces_connectivity"


class nodal_properties:
    """Contains strings to define nodal property fields.

    Attributes
    ----------
    coordinates = "coordinates"
        coordinates data is provided

    nodal_connectivity = "reverse_connectivity"
        nodal connectivity property data is provided
    """

    coordinates = "coordinates"
    nodal_connectivity = "reverse_connectivity"


class face_properties:
    """Contains strings to define face property fields.

    Attributes
    ----------
    faces_type = "faces_type"
        face type property data is provided

    faces_nodes_connectivity = "faces_nodes_connectivity"
        faces connectivity property data is provided
    """

    faces_type = "faces_type"
    faces_nodes_connectivity = "faces_nodes_connectivity"


class config_options:
    """Contains strings to define configuration options.

    Attributes
    ----------
    num_thread = "num_threads"
        number of threads

    use_cache = "use_cache"
        usage of cache if a server with gRPC communication
        protocol is used.
    """

    num_threads = "num_threads"
    use_cache = "use_cache"


class DefinitionLabels:
    """Contains Python definition labels."""

    time = "time"
    complex = "complex"


class TqdmProgressBar(ProgressBarBase):
    def __init__(self, text, unit, tot_size=None):
        import tqdm

        super().__init__(text, tot_size)
        bar_format = (
            "{l_bar}{bar}| {n_fmt} {unit}"
            if self.tot_size is None
            else "{l_bar}{bar}| {n_fmt}/{total_fmt} {unit}"
        )
        self.bar = tqdm.tqdm(
            desc=text,
            total=tot_size,
            unit=unit,
            file=sys.stdout,
            bar_format=bar_format,
            ncols=100,
        )

    def update(self, current_value):
        if self.tot_size is None:
            self.bar.total = current_value * 2
        self.bar.update(current_value - self.current)
        self.current = current_value

    @staticmethod
    def progress_available():
        return module_exists("tqdm")


def _progress_bar_is_available():
    return TqdmProgressBar.progress_available()


def _common_progress_bar(text, unit, tot_size=None):
    return TqdmProgressBar(text, unit, tot_size)


def _common_percentage_progress_bar(text):
    return TqdmProgressBar(text, "%", 100)


def type_to_internal_object_keyword():
    from ansys.dpf.core import (
        cyclic_support,
        data_sources,
        field,
        fields_container,
        meshed_region,
        meshes_container,
        property_field,
        string_field,
        custom_type_field,
        result_info,
        scoping,
        scopings_container,
        time_freq_support,
        dpf_operator,
        data_tree,
        workflow,
        streams_container,
        generic_data_container,
    )

    return {
        field.Field: "field",
        property_field.PropertyField: "property_field",
        string_field.StringField: "string_field",
        custom_type_field.CustomTypeField: "field",
        scoping.Scoping: "scoping",
        fields_container.FieldsContainer: "fields_container",
        scopings_container.ScopingsContainer: "scopings_container",
        meshes_container.MeshesContainer: "meshes_container",
        streams_container.StreamsContainer: "streams_container",
        data_sources.DataSources: "data_sources",
        cyclic_support.CyclicSupport: "cyclic_support",
        meshed_region.MeshedRegion: "mesh",
        result_info.ResultInfo: "result_info",
        time_freq_support.TimeFreqSupport: "time_freq_support",
        workflow.Workflow: "workflow",
        data_tree.DataTree: "data_tree",
        dpf_operator.Operator: "operator",
        generic_data_container.GenericDataContainer: "generic_data_container",
    }



"""
Cyclic Support
==============
"""

import traceback
import warnings

from ansys.dpf.gate import cyclic_support_capi, cyclic_support_grpcapi

from ansys.dpf.core import server as server_module
from ansys.dpf.core.scoping import Scoping


class CyclicSupport:
    """Represents a cyclic support, which describes a model with cyclic symmetry.

    The model has the necessary data for cyclic (and multistage) expansion.

    Parameters
    ----------
    cyclic_support : ansys.grpc.dpf.cyclic_support_pb2.CyclicSupport message
        Cyclic support.
    server : DPFServer , optional
        Server with the channel connected to the remote or local instance. The default is
        ``None``, in which case an attempt is made to use the global server.

    Examples
    --------
    Get a cyclic support from a model.

    >>> from ansys.dpf import core as dpf
    >>> from ansys.dpf.core import examples
    >>> multi_stage = examples.download_multi_stage_cyclic_result()
    >>> model = dpf.Model(multi_stage)
    >>> result_info = model.metadata.result_info
    >>> cyc_support = result_info.cyclic_support
    >>> cyc_support.num_sectors()
    6
    >>> cyc_support.num_stages
    2

    """

    def __init__(self, cyclic_support, server=None):
        """Initialize time frequency support with its `TimeFreqSupport` message (if possible)."""
        # step 1: get server
        self._server = server_module.get_or_create_server(server)

        # step 2: get api
        self._api = self._server.get_api_for_type(
            capi=cyclic_support_capi.CyclicSupportCAPI,
            grpcapi=cyclic_support_grpcapi.CyclicSupportGRPCAPI,
        )

        # step3: init environment
        self._api.init_cyclic_support_environment(self)  # creates stub when gRPC

        # step4: take object instance
        self._internal_obj = cyclic_support

    def __str__(self):
        """Describe the entity.

        Returns
        -------
        str
            Description of the entity.
        """
        from ansys.dpf.core.core import _description

        return _description(self._internal_obj, self._server)

    @property
    def num_stages(self) -> int:
        """Number of cyclic stages in the model

        Examples
        --------
        >>> from ansys.dpf.core import Model
        >>> from ansys.dpf.core import examples
        >>> multi_stage = examples.download_multi_stage_cyclic_result()
        >>> cyc_support = Model(multi_stage).metadata.result_info.cyclic_support
        >>> cyc_support.num_stages
        2

        Returns
        -------
        int
            Number of cyclic stages in the model.
        """
        return self._api.cyclic_support_get_num_stages(self)

    def num_sectors(self, stage_num=0) -> int:
        """Number of sectors to expand on 360 degrees.

        Parameters
        ----------
        stage_num : int , optional
            Number of the stages required (from 0 to num_stages).

        Returns
        -------
        int
            Number of sectors to expand on 360 degrees.

        Examples
        --------
        >>> from ansys.dpf.core import Model
        >>> from ansys.dpf.core import examples
        >>> multi_stage = examples.download_multi_stage_cyclic_result()
        >>> cyc_support = Model(multi_stage).metadata.result_info.cyclic_support
        >>> cyc_support.num_sectors(0)
        6
        >>> cyc_support.num_sectors(1)
        12

        """
        return self._api.cyclic_support_get_num_sectors(self, stage_num)

    def base_nodes_scoping(self, stage_num=0) -> Scoping:
        """Retrieve a nodal scoping containing node IDs in the
        base sector of the given stage.

        Parameters
        ----------
        stage_num : int, optional
            Number of the stage required (from 0 to num_stages).

        Returns
        -------
        base_nodes_scoping : Scoping
            Nodes IDs in the base sector of the given stage.

        Examples
        --------
        >>> from ansys.dpf.core import Model
        >>> from ansys.dpf.core import examples
        >>> multi_stage = examples.download_multi_stage_cyclic_result()
        >>> cyc_support = Model(multi_stage).metadata.result_info.cyclic_support
        >>> base = cyc_support.base_nodes_scoping(0)

        """
        base_node_scoping = self._api.cyclic_support_get_base_nodes_scoping(self, stage_num)
        return Scoping(scoping=base_node_scoping, server=self._server)

    def base_elements_scoping(self, stage_num=0) -> Scoping:
        """Retrieve an elemental scoping containing elements IDs in the
        base sector of the given stage.

        Parameters
        ----------
        stage_num : int, optional
            Number of the stage required (from 0 to num_stages).

        Returns
        -------
        base_elements_scoping : Scoping
            Elements ids in the base sector of the given stage.

        Examples
        --------
        >>> from ansys.dpf.core import Model
        >>> from ansys.dpf.core import examples
        >>> multi_stage = examples.download_multi_stage_cyclic_result()
        >>> cyc_support = Model(multi_stage).metadata.result_info.cyclic_support
        >>> base = cyc_support.base_elements_scoping(stage_num=1)

        """
        base_element_scoping = self._api.cyclic_support_get_base_elements_scoping(self, stage_num)
        return Scoping(scoping=base_element_scoping, server=self._server)

    def sectors_set_for_expansion(self, stage_num=0) -> Scoping:
        """Retrieve a sector's scoping of the already expanded results
        and mesh or the list of sectors that will be expanded by default.

        A sector's scoping starts from 0, with the maximum equal to num_sectors-1.

        Parameters
        ----------
        stage_num : int, optional
            Number of the stage required (from 0 to num_stages).

        Returns
        -------
        sectors_set_for_expansion : Scoping
            List of sectors (starting from 0 to max = num_sectors-1).

        Examples
        --------
        >>> from ansys.dpf.core import Model
        >>> from ansys.dpf.core import examples
        >>> multi_stage = examples.download_multi_stage_cyclic_result()
        >>> cyc_support = Model(multi_stage).metadata.result_info.cyclic_support
        >>> sectors_scoping = cyc_support.sectors_set_for_expansion(stage_num=1)
        >>> print(sectors_scoping.ids)
        [...0... 1... 2... 3... 4... 5... 6... 7... 8... 9... 10... 11]

        """
        sectors_for_expansion = self._api.cyclic_support_get_sectors_scoping(self, stage_num)
        return Scoping(scoping=sectors_for_expansion, server=self._server)

    def expand_node_id(self, node_id, sectors=None, stage_num=0):
        """Retrieve the node IDs corresponding to the base sector node ID given in the input
        after expansion.

        Parameters
        ----------
        node_id : int
            Base sector's node ID to expand.
        sectors : Scoping , list of int, optional
            List of sectors to expand (from 0 to ``num_sectors - 1``).
            The default is ``None``, in which case all sectors are expanded.
        stage_num : int, optional
            Number of the stage required (from 0 to ``num_stages``).

        Returns
        -------
        sectors_set_for_expansion : Scoping
            List of sectors (starting from 0 to ``num_sectors - 1``).

        Examples
        --------
        >>> from ansys.dpf.core import Model
        >>> from ansys.dpf.core import examples
        >>> multi_stage = examples.download_multi_stage_cyclic_result()
        >>> cyc_support = Model(multi_stage).metadata.result_info.cyclic_support
        >>> expanded_scoping = cyc_support.expand_node_id(1,stage_num=0)
        >>> print(expanded_scoping.ids)
        [...1... 3596... 5816... 8036... 10256... 12476]

        """
        if sectors is None:
            num_sectors = self._api.cyclic_support_get_num_sectors(self, stage_num)
            sectors = list(range(num_sectors))
        if isinstance(sectors, list):
            sectors = Scoping(ids=sectors, location="sectors", server=self._server)
        expanded_ids = self._api.cyclic_support_get_expanded_node_ids(
            self, node_id, stage_num, sectors
        )
        return Scoping(scoping=expanded_ids, server=self._server)

    def expand_element_id(self, element_id, sectors=None, stage_num=0):
        """Retrieves the element IDs corresponding to the base sector element ID given in the input
        after expansion.

        Parameters
        ----------
        element_id : int
            Base sector's element ID to expand.
        sectors : Scoping or list of int, optional
            List of sectors to expand (from 0 to ``num_sectors - 1``).
            The default is ``None``, in which case all sectors are expanded.
        stage_num : int, optional
            Number of the stage required (from 0 to ``num_stages``).

        Returns
        -------
        sectors_set_for_expansion : Scoping
            List of sectors (starting from 0 to ``num_sectors - 1``).

        Examples
        --------
        >>> from ansys.dpf.core import Model
        >>> from ansys.dpf.core import examples
        >>> multi_stage = examples.download_multi_stage_cyclic_result()
        >>> cyc_support = Model(multi_stage).metadata.result_info.cyclic_support
        >>> expanded_scoping = cyc_support.expand_element_id(1,stage_num=0)
        >>> print(expanded_scoping.ids)
        [...1... 1558... 2533... 3508... 4483... 5458]

        """
        if sectors is None:
            num_sectors = self._api.cyclic_support_get_num_sectors(self, stage_num)
            sectors = list(range(num_sectors))
        if isinstance(sectors, list):
            sectors = Scoping(ids=sectors, location="sectors", server=self._server)
        expanded_ids = self._api.cyclic_support_get_expanded_element_ids(
            self, element_id, stage_num, sectors
        )
        return Scoping(scoping=expanded_ids, server=self._server)

    def __del__(self):
        try:
            self._deleter_func[0](self._deleter_func[1](self))
        except:
            warnings.warn(traceback.format_exc())



"""
elemental_nodal_to_nodal_fc
===========================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class elemental_nodal_to_nodal_fc(Operator):
    """Transforms Elemental Nodal fields into Nodal fields using an averaging
    process. The result is computed on a given node's scoping. If the
    input fields are mixed shell/solid, then the fields are split by
    element shape and the output fields container has an elshape
    label.

    Parameters
    ----------
    fields_container : FieldsContainer
    mesh : MeshedRegion or MeshesContainer, optional
        The mesh region in this pin is used to
        perform the averaging. it is used if
        there is no fields support.
    should_average : bool, optional
        Each nodal value is divided by the number of
        elements linked to this node (default
        is true for discrete quantities).
    scoping : Scoping or ScopingsContainer, optional
        Average only on these nodes. if it is a
        scoping container, the label must
        correspond to the one of the fields
        containers.
    extend_to_mid_nodes : bool, optional
        Compute mid nodes (when available) by
        averaging the neighbour primary
        nodes.
    extend_weights_to_mid_nodes : bool, optional
        Extends weights to mid nodes (when
        available). default is false.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()

    >>> # Make input connections
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_should_average = bool()
    >>> op.inputs.should_average.connect(my_should_average)
    >>> my_scoping = dpf.Scoping()
    >>> op.inputs.scoping.connect(my_scoping)
    >>> my_extend_to_mid_nodes = bool()
    >>> op.inputs.extend_to_mid_nodes.connect(my_extend_to_mid_nodes)
    >>> my_extend_weights_to_mid_nodes = bool()
    >>> op.inputs.extend_weights_to_mid_nodes.connect(my_extend_weights_to_mid_nodes)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc(
    ...     fields_container=my_fields_container,
    ...     mesh=my_mesh,
    ...     should_average=my_should_average,
    ...     scoping=my_scoping,
    ...     extend_to_mid_nodes=my_extend_to_mid_nodes,
    ...     extend_weights_to_mid_nodes=my_extend_weights_to_mid_nodes,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    >>> result_weights = op.outputs.weights()
    """

    def __init__(
        self,
        fields_container=None,
        mesh=None,
        should_average=None,
        scoping=None,
        extend_to_mid_nodes=None,
        extend_weights_to_mid_nodes=None,
        config=None,
        server=None,
    ):
        super().__init__(
            name="elemental_nodal_To_nodal_fc", config=config, server=server
        )
        self._inputs = InputsElementalNodalToNodalFc(self)
        self._outputs = OutputsElementalNodalToNodalFc(self)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if mesh is not None:
            self.inputs.mesh.connect(mesh)
        if should_average is not None:
            self.inputs.should_average.connect(should_average)
        if scoping is not None:
            self.inputs.scoping.connect(scoping)
        if extend_to_mid_nodes is not None:
            self.inputs.extend_to_mid_nodes.connect(extend_to_mid_nodes)
        if extend_weights_to_mid_nodes is not None:
            self.inputs.extend_weights_to_mid_nodes.connect(extend_weights_to_mid_nodes)

    @staticmethod
    def _spec():
        description = """Transforms Elemental Nodal fields into Nodal fields using an averaging
            process. The result is computed on a given node's scoping.
            If the input fields are mixed shell/solid, then the fields
            are split by element shape and the output fields container
            has an elshape label."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="mesh",
                    type_names=["abstract_meshed_region", "meshes_container"],
                    optional=True,
                    document="""The mesh region in this pin is used to
        perform the averaging. it is used if
        there is no fields support.""",
                ),
                2: PinSpecification(
                    name="should_average",
                    type_names=["bool"],
                    optional=True,
                    document="""Each nodal value is divided by the number of
        elements linked to this node (default
        is true for discrete quantities).""",
                ),
                3: PinSpecification(
                    name="scoping",
                    type_names=["scoping", "scopings_container"],
                    optional=True,
                    document="""Average only on these nodes. if it is a
        scoping container, the label must
        correspond to the one of the fields
        containers.""",
                ),
                4: PinSpecification(
                    name="extend_to_mid_nodes",
                    type_names=["bool"],
                    optional=True,
                    document="""Compute mid nodes (when available) by
        averaging the neighbour primary
        nodes.""",
                ),
                5: PinSpecification(
                    name="extend_weights_to_mid_nodes",
                    type_names=["bool"],
                    optional=True,
                    document="""Extends weights to mid nodes (when
        available). default is false.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="weights",
                    type_names=[
                        "class dataProcessing::DpfTypeCollection<class dataProcessing::CPropertyField>"
                    ],
                    optional=False,
                    document="""Gives for each node, the number of times it
        was found in the elemental nodal
        field. can be used to average later.""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(
            name="elemental_nodal_To_nodal_fc", server=server
        )

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsElementalNodalToNodalFc
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsElementalNodalToNodalFc
        """
        return super().outputs


class InputsElementalNodalToNodalFc(_Inputs):
    """Intermediate class used to connect user inputs to
    elemental_nodal_to_nodal_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_should_average = bool()
    >>> op.inputs.should_average.connect(my_should_average)
    >>> my_scoping = dpf.Scoping()
    >>> op.inputs.scoping.connect(my_scoping)
    >>> my_extend_to_mid_nodes = bool()
    >>> op.inputs.extend_to_mid_nodes.connect(my_extend_to_mid_nodes)
    >>> my_extend_weights_to_mid_nodes = bool()
    >>> op.inputs.extend_weights_to_mid_nodes.connect(my_extend_weights_to_mid_nodes)
    """

    def __init__(self, op: Operator):
        super().__init__(elemental_nodal_to_nodal_fc._spec().inputs, op)
        self._fields_container = Input(
            elemental_nodal_to_nodal_fc._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._fields_container)
        self._mesh = Input(elemental_nodal_to_nodal_fc._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._mesh)
        self._should_average = Input(
            elemental_nodal_to_nodal_fc._spec().input_pin(2), 2, op, -1
        )
        self._inputs.append(self._should_average)
        self._scoping = Input(
            elemental_nodal_to_nodal_fc._spec().input_pin(3), 3, op, -1
        )
        self._inputs.append(self._scoping)
        self._extend_to_mid_nodes = Input(
            elemental_nodal_to_nodal_fc._spec().input_pin(4), 4, op, -1
        )
        self._inputs.append(self._extend_to_mid_nodes)
        self._extend_weights_to_mid_nodes = Input(
            elemental_nodal_to_nodal_fc._spec().input_pin(5), 5, op, -1
        )
        self._inputs.append(self._extend_weights_to_mid_nodes)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def mesh(self):
        """Allows to connect mesh input to the operator.

        The mesh region in this pin is used to
        perform the averaging. it is used if
        there is no fields support.

        Parameters
        ----------
        my_mesh : MeshedRegion or MeshesContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()
        >>> op.inputs.mesh.connect(my_mesh)
        >>> # or
        >>> op.inputs.mesh(my_mesh)
        """
        return self._mesh

    @property
    def should_average(self):
        """Allows to connect should_average input to the operator.

        Each nodal value is divided by the number of
        elements linked to this node (default
        is true for discrete quantities).

        Parameters
        ----------
        my_should_average : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()
        >>> op.inputs.should_average.connect(my_should_average)
        >>> # or
        >>> op.inputs.should_average(my_should_average)
        """
        return self._should_average

    @property
    def scoping(self):
        """Allows to connect scoping input to the operator.

        Average only on these nodes. if it is a
        scoping container, the label must
        correspond to the one of the fields
        containers.

        Parameters
        ----------
        my_scoping : Scoping or ScopingsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()
        >>> op.inputs.scoping.connect(my_scoping)
        >>> # or
        >>> op.inputs.scoping(my_scoping)
        """
        return self._scoping

    @property
    def extend_to_mid_nodes(self):
        """Allows to connect extend_to_mid_nodes input to the operator.

        Compute mid nodes (when available) by
        averaging the neighbour primary
        nodes.

        Parameters
        ----------
        my_extend_to_mid_nodes : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()
        >>> op.inputs.extend_to_mid_nodes.connect(my_extend_to_mid_nodes)
        >>> # or
        >>> op.inputs.extend_to_mid_nodes(my_extend_to_mid_nodes)
        """
        return self._extend_to_mid_nodes

    @property
    def extend_weights_to_mid_nodes(self):
        """Allows to connect extend_weights_to_mid_nodes input to the operator.

        Extends weights to mid nodes (when
        available). default is false.

        Parameters
        ----------
        my_extend_weights_to_mid_nodes : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()
        >>> op.inputs.extend_weights_to_mid_nodes.connect(my_extend_weights_to_mid_nodes)
        >>> # or
        >>> op.inputs.extend_weights_to_mid_nodes(my_extend_weights_to_mid_nodes)
        """
        return self._extend_weights_to_mid_nodes


class OutputsElementalNodalToNodalFc(_Outputs):
    """Intermediate class used to get outputs from
    elemental_nodal_to_nodal_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    >>> result_weights = op.outputs.weights()
    """

    def __init__(self, op: Operator):
        super().__init__(elemental_nodal_to_nodal_fc._spec().outputs, op)
        self._fields_container = Output(
            elemental_nodal_to_nodal_fc._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._fields_container)
        self._weights = Output(elemental_nodal_to_nodal_fc._spec().output_pin(1), 1, op)
        self._outputs.append(self._weights)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator

        Returns
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """  # noqa: E501
        return self._fields_container

    @property
    def weights(self):
        """Allows to get weights output of the operator

        Returns
        ----------
        my_weights : Class Dataprocessing::Dpftypecollection&lt;Class
        Dataprocessing::Cpropertyfield&gt;

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_nodal_to_nodal_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_weights = op.outputs.weights()
        """  # noqa: E501
        return self._weights



"""
transform_invariant_terms_rbd
=============================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class transform_invariant_terms_rbd(Operator):
    """Transform invariant terms rbd based on a coordinate system
    (translation + rotation).

    Parameters
    ----------
    rotation_matrix : Field
        3-3 rotation matrix.
    coordinate_system : Field
        Origin of the new coordinate system.
    in_cms_rbd_file_path : str
        File name with cms_rbd extension where to
        read the input cms_rbd file.
    out_cms_rbd_file_path : str
        File name with cms_rbd extension where to
        create the new cms_rbd file.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.geo.transform_invariant_terms_rbd()

    >>> # Make input connections
    >>> my_rotation_matrix = dpf.Field()
    >>> op.inputs.rotation_matrix.connect(my_rotation_matrix)
    >>> my_coordinate_system = dpf.Field()
    >>> op.inputs.coordinate_system.connect(my_coordinate_system)
    >>> my_in_cms_rbd_file_path = str()
    >>> op.inputs.in_cms_rbd_file_path.connect(my_in_cms_rbd_file_path)
    >>> my_out_cms_rbd_file_path = str()
    >>> op.inputs.out_cms_rbd_file_path.connect(my_out_cms_rbd_file_path)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.geo.transform_invariant_terms_rbd(
    ...     rotation_matrix=my_rotation_matrix,
    ...     coordinate_system=my_coordinate_system,
    ...     in_cms_rbd_file_path=my_in_cms_rbd_file_path,
    ...     out_cms_rbd_file_path=my_out_cms_rbd_file_path,
    ... )

    """

    def __init__(
        self,
        rotation_matrix=None,
        coordinate_system=None,
        in_cms_rbd_file_path=None,
        out_cms_rbd_file_path=None,
        config=None,
        server=None,
    ):
        super().__init__(
            name="transform_invariant_terms_rbd", config=config, server=server
        )
        self._inputs = InputsTransformInvariantTermsRbd(self)
        self._outputs = OutputsTransformInvariantTermsRbd(self)
        if rotation_matrix is not None:
            self.inputs.rotation_matrix.connect(rotation_matrix)
        if coordinate_system is not None:
            self.inputs.coordinate_system.connect(coordinate_system)
        if in_cms_rbd_file_path is not None:
            self.inputs.in_cms_rbd_file_path.connect(in_cms_rbd_file_path)
        if out_cms_rbd_file_path is not None:
            self.inputs.out_cms_rbd_file_path.connect(out_cms_rbd_file_path)

    @staticmethod
    def _spec():
        description = """Transform invariant terms rbd based on a coordinate system
            (translation + rotation)."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="rotation_matrix",
                    type_names=["field"],
                    optional=False,
                    document="""3-3 rotation matrix.""",
                ),
                1: PinSpecification(
                    name="coordinate_system",
                    type_names=["field"],
                    optional=False,
                    document="""Origin of the new coordinate system.""",
                ),
                2: PinSpecification(
                    name="in_cms_rbd_file_path",
                    type_names=["string"],
                    optional=False,
                    document="""File name with cms_rbd extension where to
        read the input cms_rbd file.""",
                ),
                3: PinSpecification(
                    name="out_cms_rbd_file_path",
                    type_names=["string"],
                    optional=False,
                    document="""File name with cms_rbd extension where to
        create the new cms_rbd file.""",
                ),
            },
            map_output_pin_spec={},
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(
            name="transform_invariant_terms_rbd", server=server
        )

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsTransformInvariantTermsRbd
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsTransformInvariantTermsRbd
        """
        return super().outputs


class InputsTransformInvariantTermsRbd(_Inputs):
    """Intermediate class used to connect user inputs to
    transform_invariant_terms_rbd operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.geo.transform_invariant_terms_rbd()
    >>> my_rotation_matrix = dpf.Field()
    >>> op.inputs.rotation_matrix.connect(my_rotation_matrix)
    >>> my_coordinate_system = dpf.Field()
    >>> op.inputs.coordinate_system.connect(my_coordinate_system)
    >>> my_in_cms_rbd_file_path = str()
    >>> op.inputs.in_cms_rbd_file_path.connect(my_in_cms_rbd_file_path)
    >>> my_out_cms_rbd_file_path = str()
    >>> op.inputs.out_cms_rbd_file_path.connect(my_out_cms_rbd_file_path)
    """

    def __init__(self, op: Operator):
        super().__init__(transform_invariant_terms_rbd._spec().inputs, op)
        self._rotation_matrix = Input(
            transform_invariant_terms_rbd._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._rotation_matrix)
        self._coordinate_system = Input(
            transform_invariant_terms_rbd._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._coordinate_system)
        self._in_cms_rbd_file_path = Input(
            transform_invariant_terms_rbd._spec().input_pin(2), 2, op, -1
        )
        self._inputs.append(self._in_cms_rbd_file_path)
        self._out_cms_rbd_file_path = Input(
            transform_invariant_terms_rbd._spec().input_pin(3), 3, op, -1
        )
        self._inputs.append(self._out_cms_rbd_file_path)

    @property
    def rotation_matrix(self):
        """Allows to connect rotation_matrix input to the operator.

        3-3 rotation matrix.

        Parameters
        ----------
        my_rotation_matrix : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.geo.transform_invariant_terms_rbd()
        >>> op.inputs.rotation_matrix.connect(my_rotation_matrix)
        >>> # or
        >>> op.inputs.rotation_matrix(my_rotation_matrix)
        """
        return self._rotation_matrix

    @property
    def coordinate_system(self):
        """Allows to connect coordinate_system input to the operator.

        Origin of the new coordinate system.

        Parameters
        ----------
        my_coordinate_system : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.geo.transform_invariant_terms_rbd()
        >>> op.inputs.coordinate_system.connect(my_coordinate_system)
        >>> # or
        >>> op.inputs.coordinate_system(my_coordinate_system)
        """
        return self._coordinate_system

    @property
    def in_cms_rbd_file_path(self):
        """Allows to connect in_cms_rbd_file_path input to the operator.

        File name with cms_rbd extension where to
        read the input cms_rbd file.

        Parameters
        ----------
        my_in_cms_rbd_file_path : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.geo.transform_invariant_terms_rbd()
        >>> op.inputs.in_cms_rbd_file_path.connect(my_in_cms_rbd_file_path)
        >>> # or
        >>> op.inputs.in_cms_rbd_file_path(my_in_cms_rbd_file_path)
        """
        return self._in_cms_rbd_file_path

    @property
    def out_cms_rbd_file_path(self):
        """Allows to connect out_cms_rbd_file_path input to the operator.

        File name with cms_rbd extension where to
        create the new cms_rbd file.

        Parameters
        ----------
        my_out_cms_rbd_file_path : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.geo.transform_invariant_terms_rbd()
        >>> op.inputs.out_cms_rbd_file_path.connect(my_out_cms_rbd_file_path)
        >>> # or
        >>> op.inputs.out_cms_rbd_file_path(my_out_cms_rbd_file_path)
        """
        return self._out_cms_rbd_file_path


class OutputsTransformInvariantTermsRbd(_Outputs):
    """Intermediate class used to get outputs from
    transform_invariant_terms_rbd operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.geo.transform_invariant_terms_rbd()
    >>> # Connect inputs : op.inputs. ...
    """

    def __init__(self, op: Operator):
        super().__init__(transform_invariant_terms_rbd._spec().outputs, op)



"""
fft_multi_harmonic_minmax
=========================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class fft_multi_harmonic_minmax(Operator):
    """Evaluate min max fields on multi harmonic solution. min and max fields
    are calculated based on evaluating a fourier series sum wrt rpms
    and using the gradient method for adaptive time steping

    Parameters
    ----------
    fields_container : FieldsContainer
    rpm_scoping : Scoping, optional
        Rpm scoping, by default the fourier series
        sum is evaluated using all the rpms
    fs_ratio : int, optional
        Field or fields container with only one field
        is expected
    num_subdivisions : int, optional
        Connect number subdivisions, used for uniform
        discretization
    max_num_subdivisions : int, optional
        Connect max number subdivisions, used to
        avoid huge number of sudivisions
    num_cycles : int, optional
        Number of cycle of the periodic signal
        (default is 2)
    use_harmonic_zero : bool, optional
        Use harmonic zero for first rpm (default is
        false)
    calculate_time_series : bool, optional
        Calculates time series output (output pin 2),
        setting it to false enhance
        performance if only min/max are
        required (default is true)
    substeps_selector : optional
        Substeps to evaluate (frequencies), by
        default the operator is evaluated
        using all the available steps


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.math.fft_multi_harmonic_minmax()

    >>> # Make input connections
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_rpm_scoping = dpf.Scoping()
    >>> op.inputs.rpm_scoping.connect(my_rpm_scoping)
    >>> my_fs_ratio = int()
    >>> op.inputs.fs_ratio.connect(my_fs_ratio)
    >>> my_num_subdivisions = int()
    >>> op.inputs.num_subdivisions.connect(my_num_subdivisions)
    >>> my_max_num_subdivisions = int()
    >>> op.inputs.max_num_subdivisions.connect(my_max_num_subdivisions)
    >>> my_num_cycles = int()
    >>> op.inputs.num_cycles.connect(my_num_cycles)
    >>> my_use_harmonic_zero = bool()
    >>> op.inputs.use_harmonic_zero.connect(my_use_harmonic_zero)
    >>> my_calculate_time_series = bool()
    >>> op.inputs.calculate_time_series.connect(my_calculate_time_series)
    >>> my_substeps_selector = dpf.()
    >>> op.inputs.substeps_selector.connect(my_substeps_selector)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.math.fft_multi_harmonic_minmax(
    ...     fields_container=my_fields_container,
    ...     rpm_scoping=my_rpm_scoping,
    ...     fs_ratio=my_fs_ratio,
    ...     num_subdivisions=my_num_subdivisions,
    ...     max_num_subdivisions=my_max_num_subdivisions,
    ...     num_cycles=my_num_cycles,
    ...     use_harmonic_zero=my_use_harmonic_zero,
    ...     calculate_time_series=my_calculate_time_series,
    ...     substeps_selector=my_substeps_selector,
    ... )

    >>> # Get output data
    >>> result_field_min = op.outputs.field_min()
    >>> result_field_max = op.outputs.field_max()
    >>> result_all_fields = op.outputs.all_fields()
    """

    def __init__(
        self,
        fields_container=None,
        rpm_scoping=None,
        fs_ratio=None,
        num_subdivisions=None,
        max_num_subdivisions=None,
        num_cycles=None,
        use_harmonic_zero=None,
        calculate_time_series=None,
        substeps_selector=None,
        config=None,
        server=None,
    ):
        super().__init__(name="fft_multi_harmonic_minmax", config=config, server=server)
        self._inputs = InputsFftMultiHarmonicMinmax(self)
        self._outputs = OutputsFftMultiHarmonicMinmax(self)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if rpm_scoping is not None:
            self.inputs.rpm_scoping.connect(rpm_scoping)
        if fs_ratio is not None:
            self.inputs.fs_ratio.connect(fs_ratio)
        if num_subdivisions is not None:
            self.inputs.num_subdivisions.connect(num_subdivisions)
        if max_num_subdivisions is not None:
            self.inputs.max_num_subdivisions.connect(max_num_subdivisions)
        if num_cycles is not None:
            self.inputs.num_cycles.connect(num_cycles)
        if use_harmonic_zero is not None:
            self.inputs.use_harmonic_zero.connect(use_harmonic_zero)
        if calculate_time_series is not None:
            self.inputs.calculate_time_series.connect(calculate_time_series)
        if substeps_selector is not None:
            self.inputs.substeps_selector.connect(substeps_selector)

    @staticmethod
    def _spec():
        description = """Evaluate min max fields on multi harmonic solution. min and max fields
            are calculated based on evaluating a fourier series sum
            wrt rpms and using the gradient method for adaptive time
            steping"""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="rpm_scoping",
                    type_names=["scoping"],
                    optional=True,
                    document="""Rpm scoping, by default the fourier series
        sum is evaluated using all the rpms""",
                ),
                2: PinSpecification(
                    name="fs_ratio",
                    type_names=["int32"],
                    optional=True,
                    document="""Field or fields container with only one field
        is expected""",
                ),
                3: PinSpecification(
                    name="num_subdivisions",
                    type_names=["int32"],
                    optional=True,
                    document="""Connect number subdivisions, used for uniform
        discretization""",
                ),
                4: PinSpecification(
                    name="max_num_subdivisions",
                    type_names=["int32"],
                    optional=True,
                    document="""Connect max number subdivisions, used to
        avoid huge number of sudivisions""",
                ),
                5: PinSpecification(
                    name="num_cycles",
                    type_names=["int32"],
                    optional=True,
                    document="""Number of cycle of the periodic signal
        (default is 2)""",
                ),
                6: PinSpecification(
                    name="use_harmonic_zero",
                    type_names=["bool"],
                    optional=True,
                    document="""Use harmonic zero for first rpm (default is
        false)""",
                ),
                7: PinSpecification(
                    name="calculate_time_series",
                    type_names=["bool"],
                    optional=True,
                    document="""Calculates time series output (output pin 2),
        setting it to false enhance
        performance if only min/max are
        required (default is true)""",
                ),
                8: PinSpecification(
                    name="substeps_selector",
                    type_names=["vector<int32>"],
                    optional=True,
                    document="""Substeps to evaluate (frequencies), by
        default the operator is evaluated
        using all the available steps""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="field_min",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="field_max",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                2: PinSpecification(
                    name="all_fields",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="fft_multi_harmonic_minmax", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsFftMultiHarmonicMinmax
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsFftMultiHarmonicMinmax
        """
        return super().outputs


class InputsFftMultiHarmonicMinmax(_Inputs):
    """Intermediate class used to connect user inputs to
    fft_multi_harmonic_minmax operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_rpm_scoping = dpf.Scoping()
    >>> op.inputs.rpm_scoping.connect(my_rpm_scoping)
    >>> my_fs_ratio = int()
    >>> op.inputs.fs_ratio.connect(my_fs_ratio)
    >>> my_num_subdivisions = int()
    >>> op.inputs.num_subdivisions.connect(my_num_subdivisions)
    >>> my_max_num_subdivisions = int()
    >>> op.inputs.max_num_subdivisions.connect(my_max_num_subdivisions)
    >>> my_num_cycles = int()
    >>> op.inputs.num_cycles.connect(my_num_cycles)
    >>> my_use_harmonic_zero = bool()
    >>> op.inputs.use_harmonic_zero.connect(my_use_harmonic_zero)
    >>> my_calculate_time_series = bool()
    >>> op.inputs.calculate_time_series.connect(my_calculate_time_series)
    >>> my_substeps_selector = dpf.()
    >>> op.inputs.substeps_selector.connect(my_substeps_selector)
    """

    def __init__(self, op: Operator):
        super().__init__(fft_multi_harmonic_minmax._spec().inputs, op)
        self._fields_container = Input(
            fft_multi_harmonic_minmax._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._fields_container)
        self._rpm_scoping = Input(
            fft_multi_harmonic_minmax._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._rpm_scoping)
        self._fs_ratio = Input(
            fft_multi_harmonic_minmax._spec().input_pin(2), 2, op, -1
        )
        self._inputs.append(self._fs_ratio)
        self._num_subdivisions = Input(
            fft_multi_harmonic_minmax._spec().input_pin(3), 3, op, -1
        )
        self._inputs.append(self._num_subdivisions)
        self._max_num_subdivisions = Input(
            fft_multi_harmonic_minmax._spec().input_pin(4), 4, op, -1
        )
        self._inputs.append(self._max_num_subdivisions)
        self._num_cycles = Input(
            fft_multi_harmonic_minmax._spec().input_pin(5), 5, op, -1
        )
        self._inputs.append(self._num_cycles)
        self._use_harmonic_zero = Input(
            fft_multi_harmonic_minmax._spec().input_pin(6), 6, op, -1
        )
        self._inputs.append(self._use_harmonic_zero)
        self._calculate_time_series = Input(
            fft_multi_harmonic_minmax._spec().input_pin(7), 7, op, -1
        )
        self._inputs.append(self._calculate_time_series)
        self._substeps_selector = Input(
            fft_multi_harmonic_minmax._spec().input_pin(8), 8, op, -1
        )
        self._inputs.append(self._substeps_selector)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def rpm_scoping(self):
        """Allows to connect rpm_scoping input to the operator.

        Rpm scoping, by default the fourier series
        sum is evaluated using all the rpms

        Parameters
        ----------
        my_rpm_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> op.inputs.rpm_scoping.connect(my_rpm_scoping)
        >>> # or
        >>> op.inputs.rpm_scoping(my_rpm_scoping)
        """
        return self._rpm_scoping

    @property
    def fs_ratio(self):
        """Allows to connect fs_ratio input to the operator.

        Field or fields container with only one field
        is expected

        Parameters
        ----------
        my_fs_ratio : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> op.inputs.fs_ratio.connect(my_fs_ratio)
        >>> # or
        >>> op.inputs.fs_ratio(my_fs_ratio)
        """
        return self._fs_ratio

    @property
    def num_subdivisions(self):
        """Allows to connect num_subdivisions input to the operator.

        Connect number subdivisions, used for uniform
        discretization

        Parameters
        ----------
        my_num_subdivisions : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> op.inputs.num_subdivisions.connect(my_num_subdivisions)
        >>> # or
        >>> op.inputs.num_subdivisions(my_num_subdivisions)
        """
        return self._num_subdivisions

    @property
    def max_num_subdivisions(self):
        """Allows to connect max_num_subdivisions input to the operator.

        Connect max number subdivisions, used to
        avoid huge number of sudivisions

        Parameters
        ----------
        my_max_num_subdivisions : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> op.inputs.max_num_subdivisions.connect(my_max_num_subdivisions)
        >>> # or
        >>> op.inputs.max_num_subdivisions(my_max_num_subdivisions)
        """
        return self._max_num_subdivisions

    @property
    def num_cycles(self):
        """Allows to connect num_cycles input to the operator.

        Number of cycle of the periodic signal
        (default is 2)

        Parameters
        ----------
        my_num_cycles : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> op.inputs.num_cycles.connect(my_num_cycles)
        >>> # or
        >>> op.inputs.num_cycles(my_num_cycles)
        """
        return self._num_cycles

    @property
    def use_harmonic_zero(self):
        """Allows to connect use_harmonic_zero input to the operator.

        Use harmonic zero for first rpm (default is
        false)

        Parameters
        ----------
        my_use_harmonic_zero : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> op.inputs.use_harmonic_zero.connect(my_use_harmonic_zero)
        >>> # or
        >>> op.inputs.use_harmonic_zero(my_use_harmonic_zero)
        """
        return self._use_harmonic_zero

    @property
    def calculate_time_series(self):
        """Allows to connect calculate_time_series input to the operator.

        Calculates time series output (output pin 2),
        setting it to false enhance
        performance if only min/max are
        required (default is true)

        Parameters
        ----------
        my_calculate_time_series : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> op.inputs.calculate_time_series.connect(my_calculate_time_series)
        >>> # or
        >>> op.inputs.calculate_time_series(my_calculate_time_series)
        """
        return self._calculate_time_series

    @property
    def substeps_selector(self):
        """Allows to connect substeps_selector input to the operator.

        Substeps to evaluate (frequencies), by
        default the operator is evaluated
        using all the available steps

        Parameters
        ----------
        my_substeps_selector :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> op.inputs.substeps_selector.connect(my_substeps_selector)
        >>> # or
        >>> op.inputs.substeps_selector(my_substeps_selector)
        """
        return self._substeps_selector


class OutputsFftMultiHarmonicMinmax(_Outputs):
    """Intermediate class used to get outputs from
    fft_multi_harmonic_minmax operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
    >>> # Connect inputs : op.inputs. ...
    >>> result_field_min = op.outputs.field_min()
    >>> result_field_max = op.outputs.field_max()
    >>> result_all_fields = op.outputs.all_fields()
    """

    def __init__(self, op: Operator):
        super().__init__(fft_multi_harmonic_minmax._spec().outputs, op)
        self._field_min = Output(fft_multi_harmonic_minmax._spec().output_pin(0), 0, op)
        self._outputs.append(self._field_min)
        self._field_max = Output(fft_multi_harmonic_minmax._spec().output_pin(1), 1, op)
        self._outputs.append(self._field_max)
        self._all_fields = Output(
            fft_multi_harmonic_minmax._spec().output_pin(2), 2, op
        )
        self._outputs.append(self._all_fields)

    @property
    def field_min(self):
        """Allows to get field_min output of the operator

        Returns
        ----------
        my_field_min : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field_min = op.outputs.field_min()
        """  # noqa: E501
        return self._field_min

    @property
    def field_max(self):
        """Allows to get field_max output of the operator

        Returns
        ----------
        my_field_max : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field_max = op.outputs.field_max()
        """  # noqa: E501
        return self._field_max

    @property
    def all_fields(self):
        """Allows to get all_fields output of the operator

        Returns
        ----------
        my_all_fields : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_multi_harmonic_minmax()
        >>> # Connect inputs : op.inputs. ...
        >>> result_all_fields = op.outputs.all_fields()
        """  # noqa: E501
        return self._all_fields



"""
gauss_to_node_fc
================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class gauss_to_node_fc(Operator):
    """Extrapolates results available at Gauss or quadrature points to nodal
    points for a field container. The available elements are: Linear
    quadrangle, parabolic quadrangle, linear hexagonal, quadratic
    hexagonal, linear tetrahedral, and quadratic tetrahedral.

    Parameters
    ----------
    fields_container : FieldsContainer
    mesh : MeshedRegion or MeshesContainer, optional
        The mesh region in this pin is used for
        extrapolating results available at
        gauss or quadrature points to nodal
        points.
    scoping : Scoping, optional
        Extrapolating results on the selected
        scoping. if it is a scoping
        container, the label must correspond
        to the one of the fields containers.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.averaging.gauss_to_node_fc()

    >>> # Make input connections
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_scoping = dpf.Scoping()
    >>> op.inputs.scoping.connect(my_scoping)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.averaging.gauss_to_node_fc(
    ...     fields_container=my_fields_container,
    ...     mesh=my_mesh,
    ...     scoping=my_scoping,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(
        self, fields_container=None, mesh=None, scoping=None, config=None, server=None
    ):
        super().__init__(name="gauss_to_node_fc", config=config, server=server)
        self._inputs = InputsGaussToNodeFc(self)
        self._outputs = OutputsGaussToNodeFc(self)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if mesh is not None:
            self.inputs.mesh.connect(mesh)
        if scoping is not None:
            self.inputs.scoping.connect(scoping)

    @staticmethod
    def _spec():
        description = """Extrapolates results available at Gauss or quadrature points to nodal
            points for a field container. The available elements are:
            Linear quadrangle, parabolic quadrangle, linear hexagonal,
            quadratic hexagonal, linear tetrahedral, and quadratic
            tetrahedral."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="mesh",
                    type_names=["abstract_meshed_region", "meshes_container"],
                    optional=True,
                    document="""The mesh region in this pin is used for
        extrapolating results available at
        gauss or quadrature points to nodal
        points.""",
                ),
                3: PinSpecification(
                    name="scoping",
                    type_names=["scoping"],
                    optional=True,
                    document="""Extrapolating results on the selected
        scoping. if it is a scoping
        container, the label must correspond
        to the one of the fields containers.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="gauss_to_node_fc", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsGaussToNodeFc
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsGaussToNodeFc
        """
        return super().outputs


class InputsGaussToNodeFc(_Inputs):
    """Intermediate class used to connect user inputs to
    gauss_to_node_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.averaging.gauss_to_node_fc()
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_scoping = dpf.Scoping()
    >>> op.inputs.scoping.connect(my_scoping)
    """

    def __init__(self, op: Operator):
        super().__init__(gauss_to_node_fc._spec().inputs, op)
        self._fields_container = Input(gauss_to_node_fc._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._fields_container)
        self._mesh = Input(gauss_to_node_fc._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._mesh)
        self._scoping = Input(gauss_to_node_fc._spec().input_pin(3), 3, op, -1)
        self._inputs.append(self._scoping)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.gauss_to_node_fc()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def mesh(self):
        """Allows to connect mesh input to the operator.

        The mesh region in this pin is used for
        extrapolating results available at
        gauss or quadrature points to nodal
        points.

        Parameters
        ----------
        my_mesh : MeshedRegion or MeshesContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.gauss_to_node_fc()
        >>> op.inputs.mesh.connect(my_mesh)
        >>> # or
        >>> op.inputs.mesh(my_mesh)
        """
        return self._mesh

    @property
    def scoping(self):
        """Allows to connect scoping input to the operator.

        Extrapolating results on the selected
        scoping. if it is a scoping
        container, the label must correspond
        to the one of the fields containers.

        Parameters
        ----------
        my_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.gauss_to_node_fc()
        >>> op.inputs.scoping.connect(my_scoping)
        >>> # or
        >>> op.inputs.scoping(my_scoping)
        """
        return self._scoping


class OutputsGaussToNodeFc(_Outputs):
    """Intermediate class used to get outputs from
    gauss_to_node_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.averaging.gauss_to_node_fc()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, op: Operator):
        super().__init__(gauss_to_node_fc._spec().outputs, op)
        self._fields_container = Output(gauss_to_node_fc._spec().output_pin(0), 0, op)
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator

        Returns
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.gauss_to_node_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """  # noqa: E501
        return self._fields_container



"""
weighted_merge_fields_by_label
==============================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class weighted_merge_fields_by_label(Operator):
    """Performs a weighted merge on fields of a fields container that share
    the same label value.

    Parameters
    ----------
    fields_container : FieldsContainer
    label : str
        Label identifier that should be merged.
    merged_field_support : AbstractFieldSupport, optional
        The fieldscontainer's support that has
        already been merged.
    sum_merge : bool, optional
        Default is false. if true, redundant
        quantities are summed instead of
        being ignored.
    weights1 : PropertyField
        Weights to apply to each field from pin 1000
        to ...
    weights2 : PropertyField
        Weights to apply to each field from pin 1000
        to ...


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.utility.weighted_merge_fields_by_label()

    >>> # Make input connections
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_label = str()
    >>> op.inputs.label.connect(my_label)
    >>> my_merged_field_support = dpf.AbstractFieldSupport()
    >>> op.inputs.merged_field_support.connect(my_merged_field_support)
    >>> my_sum_merge = bool()
    >>> op.inputs.sum_merge.connect(my_sum_merge)
    >>> my_weights1 = dpf.PropertyField()
    >>> op.inputs.weights1.connect(my_weights1)
    >>> my_weights2 = dpf.PropertyField()
    >>> op.inputs.weights2.connect(my_weights2)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.utility.weighted_merge_fields_by_label(
    ...     fields_container=my_fields_container,
    ...     label=my_label,
    ...     merged_field_support=my_merged_field_support,
    ...     sum_merge=my_sum_merge,
    ...     weights1=my_weights1,
    ...     weights2=my_weights2,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(
        self,
        fields_container=None,
        label=None,
        merged_field_support=None,
        sum_merge=None,
        weights1=None,
        weights2=None,
        config=None,
        server=None,
    ):
        super().__init__(
            name="merge::weighted_fields_container_label", config=config, server=server
        )
        self._inputs = InputsWeightedMergeFieldsByLabel(self)
        self._outputs = OutputsWeightedMergeFieldsByLabel(self)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if label is not None:
            self.inputs.label.connect(label)
        if merged_field_support is not None:
            self.inputs.merged_field_support.connect(merged_field_support)
        if sum_merge is not None:
            self.inputs.sum_merge.connect(sum_merge)
        if weights1 is not None:
            self.inputs.weights1.connect(weights1)
        if weights2 is not None:
            self.inputs.weights2.connect(weights2)

    @staticmethod
    def _spec():
        description = """Performs a weighted merge on fields of a fields container that share
            the same label value."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="label",
                    type_names=["string"],
                    optional=False,
                    document="""Label identifier that should be merged.""",
                ),
                2: PinSpecification(
                    name="merged_field_support",
                    type_names=["abstract_field_support"],
                    optional=True,
                    document="""The fieldscontainer's support that has
        already been merged.""",
                ),
                3: PinSpecification(
                    name="sum_merge",
                    type_names=["bool"],
                    optional=True,
                    document="""Default is false. if true, redundant
        quantities are summed instead of
        being ignored.""",
                ),
                1000: PinSpecification(
                    name="weights",
                    type_names=["property_field"],
                    optional=False,
                    document="""Weights to apply to each field from pin 1000
        to ...""",
                ),
                1001: PinSpecification(
                    name="weights",
                    type_names=["property_field"],
                    optional=False,
                    document="""Weights to apply to each field from pin 1000
        to ...""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(
            name="merge::weighted_fields_container_label", server=server
        )

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsWeightedMergeFieldsByLabel
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsWeightedMergeFieldsByLabel
        """
        return super().outputs


class InputsWeightedMergeFieldsByLabel(_Inputs):
    """Intermediate class used to connect user inputs to
    weighted_merge_fields_by_label operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.weighted_merge_fields_by_label()
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_label = str()
    >>> op.inputs.label.connect(my_label)
    >>> my_merged_field_support = dpf.AbstractFieldSupport()
    >>> op.inputs.merged_field_support.connect(my_merged_field_support)
    >>> my_sum_merge = bool()
    >>> op.inputs.sum_merge.connect(my_sum_merge)
    >>> my_weights1 = dpf.PropertyField()
    >>> op.inputs.weights1.connect(my_weights1)
    >>> my_weights2 = dpf.PropertyField()
    >>> op.inputs.weights2.connect(my_weights2)
    """

    def __init__(self, op: Operator):
        super().__init__(weighted_merge_fields_by_label._spec().inputs, op)
        self._fields_container = Input(
            weighted_merge_fields_by_label._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._fields_container)
        self._label = Input(
            weighted_merge_fields_by_label._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._label)
        self._merged_field_support = Input(
            weighted_merge_fields_by_label._spec().input_pin(2), 2, op, -1
        )
        self._inputs.append(self._merged_field_support)
        self._sum_merge = Input(
            weighted_merge_fields_by_label._spec().input_pin(3), 3, op, -1
        )
        self._inputs.append(self._sum_merge)
        self._weights1 = Input(
            weighted_merge_fields_by_label._spec().input_pin(1000), 1000, op, 0
        )
        self._inputs.append(self._weights1)
        self._weights2 = Input(
            weighted_merge_fields_by_label._spec().input_pin(1001), 1001, op, 1
        )
        self._inputs.append(self._weights2)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.weighted_merge_fields_by_label()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def label(self):
        """Allows to connect label input to the operator.

        Label identifier that should be merged.

        Parameters
        ----------
        my_label : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.weighted_merge_fields_by_label()
        >>> op.inputs.label.connect(my_label)
        >>> # or
        >>> op.inputs.label(my_label)
        """
        return self._label

    @property
    def merged_field_support(self):
        """Allows to connect merged_field_support input to the operator.

        The fieldscontainer's support that has
        already been merged.

        Parameters
        ----------
        my_merged_field_support : AbstractFieldSupport

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.weighted_merge_fields_by_label()
        >>> op.inputs.merged_field_support.connect(my_merged_field_support)
        >>> # or
        >>> op.inputs.merged_field_support(my_merged_field_support)
        """
        return self._merged_field_support

    @property
    def sum_merge(self):
        """Allows to connect sum_merge input to the operator.

        Default is false. if true, redundant
        quantities are summed instead of
        being ignored.

        Parameters
        ----------
        my_sum_merge : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.weighted_merge_fields_by_label()
        >>> op.inputs.sum_merge.connect(my_sum_merge)
        >>> # or
        >>> op.inputs.sum_merge(my_sum_merge)
        """
        return self._sum_merge

    @property
    def weights1(self):
        """Allows to connect weights1 input to the operator.

        Weights to apply to each field from pin 1000
        to ...

        Parameters
        ----------
        my_weights1 : PropertyField

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.weighted_merge_fields_by_label()
        >>> op.inputs.weights1.connect(my_weights1)
        >>> # or
        >>> op.inputs.weights1(my_weights1)
        """
        return self._weights1

    @property
    def weights2(self):
        """Allows to connect weights2 input to the operator.

        Weights to apply to each field from pin 1000
        to ...

        Parameters
        ----------
        my_weights2 : PropertyField

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.weighted_merge_fields_by_label()
        >>> op.inputs.weights2.connect(my_weights2)
        >>> # or
        >>> op.inputs.weights2(my_weights2)
        """
        return self._weights2


class OutputsWeightedMergeFieldsByLabel(_Outputs):
    """Intermediate class used to get outputs from
    weighted_merge_fields_by_label operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.weighted_merge_fields_by_label()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, op: Operator):
        super().__init__(weighted_merge_fields_by_label._spec().outputs, op)
        self._fields_container = Output(
            weighted_merge_fields_by_label._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator

        Returns
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.weighted_merge_fields_by_label()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """  # noqa: E501
        return self._fields_container



"""
server_path
===========
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class server_path(Operator):
    """Returns the platform-specific path to a folder in the Dpf server

    Parameters
    ----------
    subpath : int, optional
        Subpath of the dpf server. supported values:
        0 (default): root of the server, 1:
        "dpf/bin/platform", 2:
        "aisol/bin(dll)/platform", 3:
        "dpf/plugins".


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.utility.server_path()

    >>> # Make input connections
    >>> my_subpath = int()
    >>> op.inputs.subpath.connect(my_subpath)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.utility.server_path(
    ...     subpath=my_subpath,
    ... )

    >>> # Get output data
    >>> result_path = op.outputs.path()
    """

    def __init__(self, subpath=None, config=None, server=None):
        super().__init__(name="server_path", config=config, server=server)
        self._inputs = InputsServerPath(self)
        self._outputs = OutputsServerPath(self)
        if subpath is not None:
            self.inputs.subpath.connect(subpath)

    @staticmethod
    def _spec():
        description = (
            """Returns the platform-specific path to a folder in the Dpf server"""
        )
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="subpath",
                    type_names=["int32"],
                    optional=True,
                    document="""Subpath of the dpf server. supported values:
        0 (default): root of the server, 1:
        "dpf/bin/platform", 2:
        "aisol/bin(dll)/platform", 3:
        "dpf/plugins".""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="path",
                    type_names=["string"],
                    optional=False,
                    document="""Path to the requested folder in the dpf
        server""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="server_path", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsServerPath
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsServerPath
        """
        return super().outputs


class InputsServerPath(_Inputs):
    """Intermediate class used to connect user inputs to
    server_path operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.server_path()
    >>> my_subpath = int()
    >>> op.inputs.subpath.connect(my_subpath)
    """

    def __init__(self, op: Operator):
        super().__init__(server_path._spec().inputs, op)
        self._subpath = Input(server_path._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._subpath)

    @property
    def subpath(self):
        """Allows to connect subpath input to the operator.

        Subpath of the dpf server. supported values:
        0 (default): root of the server, 1:
        "dpf/bin/platform", 2:
        "aisol/bin(dll)/platform", 3:
        "dpf/plugins".

        Parameters
        ----------
        my_subpath : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.server_path()
        >>> op.inputs.subpath.connect(my_subpath)
        >>> # or
        >>> op.inputs.subpath(my_subpath)
        """
        return self._subpath


class OutputsServerPath(_Outputs):
    """Intermediate class used to get outputs from
    server_path operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.server_path()
    >>> # Connect inputs : op.inputs. ...
    >>> result_path = op.outputs.path()
    """

    def __init__(self, op: Operator):
        super().__init__(server_path._spec().outputs, op)
        self._path = Output(server_path._spec().output_pin(0), 0, op)
        self._outputs.append(self._path)

    @property
    def path(self):
        """Allows to get path output of the operator

        Returns
        ----------
        my_path : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.server_path()
        >>> # Connect inputs : op.inputs. ...
        >>> result_path = op.outputs.path()
        """  # noqa: E501
        return self._path



"""
ds_get_attribute
================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.outputs import _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class ds_get_attribute(Operator):
    """A DataSources in pin 0 and a property name (string) in pin 1 are
    expected in input. An index refering to the property can also be
    provided.

    Parameters
    ----------
    data_sources : DataSources
    property_name : str
        Accepted inputs are: 'file_path' (returns
        string), 'result_file_name' (returns
        string), 'domain_file_path' (returns
        string), 'domain_result_file_name'
        (returns string), 'num_keys' (returns
        int), num_result_key (returns int),
        num_file_path (returns int),
        'num_result_file_path' (returns int),
        'key_by_index' (returns string),
        'result_key_by_index' (returns
        string), 'path_by_index' (returns
        string), 'path_key_by_index' (returns
        string).
    property_index : int, optional
        Index for the property. must be set for
        'domain_file_path',
        'domain_result_file_name'
        'key_by_index',
        'result_key_by_index',
        'path_by_index' and
        'path_key_by_index' properties.
    property_key : str, optional
        Key to look for. must be set for 'file_path'
        and 'domain_file_path' properties.
    property_result_key : str, optional
        Result key to look for. can be used for
        'file_path', 'result_file_name',
        'domain_file_path' and
        'domain_result_file_name'.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.utility.ds_get_attribute()

    >>> # Make input connections
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_property_name = str()
    >>> op.inputs.property_name.connect(my_property_name)
    >>> my_property_index = int()
    >>> op.inputs.property_index.connect(my_property_index)
    >>> my_property_key = str()
    >>> op.inputs.property_key.connect(my_property_key)
    >>> my_property_result_key = str()
    >>> op.inputs.property_result_key.connect(my_property_result_key)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.utility.ds_get_attribute(
    ...     data_sources=my_data_sources,
    ...     property_name=my_property_name,
    ...     property_index=my_property_index,
    ...     property_key=my_property_key,
    ...     property_result_key=my_property_result_key,
    ... )

    >>> # Get output data
    >>> result_property = op.outputs.property()
    """

    def __init__(
        self,
        data_sources=None,
        property_name=None,
        property_index=None,
        property_key=None,
        property_result_key=None,
        config=None,
        server=None,
    ):
        super().__init__(
            name="datasources::get_attribute", config=config, server=server
        )
        self._inputs = InputsDsGetAttribute(self)
        self._outputs = OutputsDsGetAttribute(self)
        if data_sources is not None:
            self.inputs.data_sources.connect(data_sources)
        if property_name is not None:
            self.inputs.property_name.connect(property_name)
        if property_index is not None:
            self.inputs.property_index.connect(property_index)
        if property_key is not None:
            self.inputs.property_key.connect(property_key)
        if property_result_key is not None:
            self.inputs.property_result_key.connect(property_result_key)

    @staticmethod
    def _spec():
        description = """A DataSources in pin 0 and a property name (string) in pin 1 are
            expected in input. An index refering to the property can
            also be provided."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="data_sources",
                    type_names=["data_sources"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="property_name",
                    type_names=["string"],
                    optional=False,
                    document="""Accepted inputs are: 'file_path' (returns
        string), 'result_file_name' (returns
        string), 'domain_file_path' (returns
        string), 'domain_result_file_name'
        (returns string), 'num_keys' (returns
        int), num_result_key (returns int),
        num_file_path (returns int),
        'num_result_file_path' (returns int),
        'key_by_index' (returns string),
        'result_key_by_index' (returns
        string), 'path_by_index' (returns
        string), 'path_key_by_index' (returns
        string).""",
                ),
                2: PinSpecification(
                    name="property_index",
                    type_names=["int32"],
                    optional=True,
                    document="""Index for the property. must be set for
        'domain_file_path',
        'domain_result_file_name'
        'key_by_index',
        'result_key_by_index',
        'path_by_index' and
        'path_key_by_index' properties.""",
                ),
                3: PinSpecification(
                    name="property_key",
                    type_names=["string"],
                    optional=True,
                    document="""Key to look for. must be set for 'file_path'
        and 'domain_file_path' properties.""",
                ),
                4: PinSpecification(
                    name="property_result_key",
                    type_names=["string"],
                    optional=True,
                    document="""Result key to look for. can be used for
        'file_path', 'result_file_name',
        'domain_file_path' and
        'domain_result_file_name'.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="property",
                    type_names=["string", "int32"],
                    optional=False,
                    document="""Property value.""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="datasources::get_attribute", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsDsGetAttribute
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsDsGetAttribute
        """
        return super().outputs


class InputsDsGetAttribute(_Inputs):
    """Intermediate class used to connect user inputs to
    ds_get_attribute operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.ds_get_attribute()
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_property_name = str()
    >>> op.inputs.property_name.connect(my_property_name)
    >>> my_property_index = int()
    >>> op.inputs.property_index.connect(my_property_index)
    >>> my_property_key = str()
    >>> op.inputs.property_key.connect(my_property_key)
    >>> my_property_result_key = str()
    >>> op.inputs.property_result_key.connect(my_property_result_key)
    """

    def __init__(self, op: Operator):
        super().__init__(ds_get_attribute._spec().inputs, op)
        self._data_sources = Input(ds_get_attribute._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._data_sources)
        self._property_name = Input(ds_get_attribute._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._property_name)
        self._property_index = Input(ds_get_attribute._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._property_index)
        self._property_key = Input(ds_get_attribute._spec().input_pin(3), 3, op, -1)
        self._inputs.append(self._property_key)
        self._property_result_key = Input(
            ds_get_attribute._spec().input_pin(4), 4, op, -1
        )
        self._inputs.append(self._property_result_key)

    @property
    def data_sources(self):
        """Allows to connect data_sources input to the operator.

        Parameters
        ----------
        my_data_sources : DataSources

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.ds_get_attribute()
        >>> op.inputs.data_sources.connect(my_data_sources)
        >>> # or
        >>> op.inputs.data_sources(my_data_sources)
        """
        return self._data_sources

    @property
    def property_name(self):
        """Allows to connect property_name input to the operator.

        Accepted inputs are: 'file_path' (returns
        string), 'result_file_name' (returns
        string), 'domain_file_path' (returns
        string), 'domain_result_file_name'
        (returns string), 'num_keys' (returns
        int), num_result_key (returns int),
        num_file_path (returns int),
        'num_result_file_path' (returns int),
        'key_by_index' (returns string),
        'result_key_by_index' (returns
        string), 'path_by_index' (returns
        string), 'path_key_by_index' (returns
        string).

        Parameters
        ----------
        my_property_name : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.ds_get_attribute()
        >>> op.inputs.property_name.connect(my_property_name)
        >>> # or
        >>> op.inputs.property_name(my_property_name)
        """
        return self._property_name

    @property
    def property_index(self):
        """Allows to connect property_index input to the operator.

        Index for the property. must be set for
        'domain_file_path',
        'domain_result_file_name'
        'key_by_index',
        'result_key_by_index',
        'path_by_index' and
        'path_key_by_index' properties.

        Parameters
        ----------
        my_property_index : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.ds_get_attribute()
        >>> op.inputs.property_index.connect(my_property_index)
        >>> # or
        >>> op.inputs.property_index(my_property_index)
        """
        return self._property_index

    @property
    def property_key(self):
        """Allows to connect property_key input to the operator.

        Key to look for. must be set for 'file_path'
        and 'domain_file_path' properties.

        Parameters
        ----------
        my_property_key : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.ds_get_attribute()
        >>> op.inputs.property_key.connect(my_property_key)
        >>> # or
        >>> op.inputs.property_key(my_property_key)
        """
        return self._property_key

    @property
    def property_result_key(self):
        """Allows to connect property_result_key input to the operator.

        Result key to look for. can be used for
        'file_path', 'result_file_name',
        'domain_file_path' and
        'domain_result_file_name'.

        Parameters
        ----------
        my_property_result_key : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.ds_get_attribute()
        >>> op.inputs.property_result_key.connect(my_property_result_key)
        >>> # or
        >>> op.inputs.property_result_key(my_property_result_key)
        """
        return self._property_result_key


class OutputsDsGetAttribute(_Outputs):
    """Intermediate class used to get outputs from
    ds_get_attribute operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.ds_get_attribute()
    >>> # Connect inputs : op.inputs. ...
    >>> result_property = op.outputs.property()
    """

    def __init__(self, op: Operator):
        super().__init__(ds_get_attribute._spec().outputs, op)
        self.property_as_string = Output(
            _modify_output_spec_with_one_type(
                ds_get_attribute._spec().output_pin(0), "string"
            ),
            0,
            op,
        )
        self._outputs.append(self.property_as_string)
        self.property_as_int32 = Output(
            _modify_output_spec_with_one_type(
                ds_get_attribute._spec().output_pin(0), "int32"
            ),
            0,
            op,
        )
        self._outputs.append(self.property_as_int32)



"""
fft_gradient_eval
=================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class fft_gradient_eval(Operator):
    """Evaluate min max based on the fast fourier transform at a given field,
    using gradient method for adaptative time step.

    Parameters
    ----------
    fields_container : FieldsContainer
    time_scoping : Scoping, optional
        If specified only the results at these set
        ids are used
    fs_ratio : int, optional
        Default value = 20


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.math.fft_gradient_eval()

    >>> # Make input connections
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_time_scoping = dpf.Scoping()
    >>> op.inputs.time_scoping.connect(my_time_scoping)
    >>> my_fs_ratio = int()
    >>> op.inputs.fs_ratio.connect(my_fs_ratio)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.math.fft_gradient_eval(
    ...     fields_container=my_fields_container,
    ...     time_scoping=my_time_scoping,
    ...     fs_ratio=my_fs_ratio,
    ... )

    >>> # Get output data
    >>> result_coefficients = op.outputs.coefficients()
    """

    def __init__(
        self,
        fields_container=None,
        time_scoping=None,
        fs_ratio=None,
        config=None,
        server=None,
    ):
        super().__init__(name="fft_eval_gr", config=config, server=server)
        self._inputs = InputsFftGradientEval(self)
        self._outputs = OutputsFftGradientEval(self)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if time_scoping is not None:
            self.inputs.time_scoping.connect(time_scoping)
        if fs_ratio is not None:
            self.inputs.fs_ratio.connect(fs_ratio)

    @staticmethod
    def _spec():
        description = """Evaluate min max based on the fast fourier transform at a given field,
            using gradient method for adaptative time step."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="time_scoping",
                    type_names=["scoping"],
                    optional=True,
                    document="""If specified only the results at these set
        ids are used""",
                ),
                2: PinSpecification(
                    name="fs_ratio",
                    type_names=["int32"],
                    optional=True,
                    document="""Default value = 20""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="coefficients",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="fft_eval_gr", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsFftGradientEval
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsFftGradientEval
        """
        return super().outputs


class InputsFftGradientEval(_Inputs):
    """Intermediate class used to connect user inputs to
    fft_gradient_eval operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.math.fft_gradient_eval()
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_time_scoping = dpf.Scoping()
    >>> op.inputs.time_scoping.connect(my_time_scoping)
    >>> my_fs_ratio = int()
    >>> op.inputs.fs_ratio.connect(my_fs_ratio)
    """

    def __init__(self, op: Operator):
        super().__init__(fft_gradient_eval._spec().inputs, op)
        self._fields_container = Input(
            fft_gradient_eval._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._fields_container)
        self._time_scoping = Input(fft_gradient_eval._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._time_scoping)
        self._fs_ratio = Input(fft_gradient_eval._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._fs_ratio)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_gradient_eval()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def time_scoping(self):
        """Allows to connect time_scoping input to the operator.

        If specified only the results at these set
        ids are used

        Parameters
        ----------
        my_time_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_gradient_eval()
        >>> op.inputs.time_scoping.connect(my_time_scoping)
        >>> # or
        >>> op.inputs.time_scoping(my_time_scoping)
        """
        return self._time_scoping

    @property
    def fs_ratio(self):
        """Allows to connect fs_ratio input to the operator.

        Default value = 20

        Parameters
        ----------
        my_fs_ratio : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_gradient_eval()
        >>> op.inputs.fs_ratio.connect(my_fs_ratio)
        >>> # or
        >>> op.inputs.fs_ratio(my_fs_ratio)
        """
        return self._fs_ratio


class OutputsFftGradientEval(_Outputs):
    """Intermediate class used to get outputs from
    fft_gradient_eval operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.math.fft_gradient_eval()
    >>> # Connect inputs : op.inputs. ...
    >>> result_coefficients = op.outputs.coefficients()
    """

    def __init__(self, op: Operator):
        super().__init__(fft_gradient_eval._spec().outputs, op)
        self._coefficients = Output(fft_gradient_eval._spec().output_pin(0), 0, op)
        self._outputs.append(self._coefficients)

    @property
    def coefficients(self):
        """Allows to get coefficients output of the operator

        Returns
        ----------
        my_coefficients : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.math.fft_gradient_eval()
        >>> # Connect inputs : op.inputs. ...
        >>> result_coefficients = op.outputs.coefficients()
        """  # noqa: E501
        return self._coefficients
